#----------------------------------------------------------------------------
# Name:         logUtil.py
# Purpose:      logging utilities
#
# Author:       Walter Obweger
#
# Created:      20191223
# CVS-ID:       $Id$
# Copyright:    (c) 2019 by Walter Obweger
# Licence:      MIT
#----------------------------------------------------------------------------

import logging
import logging.handlers
import traceback

import lindworm.ldmOS as ldmOS

lngFileHandler=None
iVerbose=0

def logInit(sLogFN,sLogger='',iLevel=logging.DEBUG,iNameLen=6):
    """initialize logging
    sLogFN      ... filename
    sLogger     ... module log name
    iLevel      ... detail level
    iNameLen    ... module name length of formatting
    return 
    """
    # +++++ beg:info
    global lngFileHandler
    if iVerbose>0:
        print('logInit:%s'%(sLogFN))
    # ----- end:info
    # +++++ beg:build FN
    try:
        iRet,sBldFN=ldmOS.bldFN(sLogFN,sExt='log')
        if iRet>0:
            sLogFN=sBldFN
    except:
        pass
    # ----- end:build FN
    # +++++ beg:prepare logging
    lngFileHandler=logging.handlers.RotatingFileHandler(sLogFN,backupCount=9)
    lngFileHandler.setLevel(iLevel)
    sFmt='%(asctime)s|%(name)-'+'%d'%(iNameLen)+'s|%(levelname)-8s|%(message)s'
    formatter=logging.Formatter(sFmt)
    lngFileHandler.setFormatter(formatter)
    lngFileHandler.doRollover()
    if iVerbose>0:
        print('lngFileHandler:%r'%(lngFileHandler))
    # ----- end:prepare logging
    # +++++ beg:add root logger
    logging.getLogger('').setLevel(iLevel)
    logging.getLogger('').addHandler(lngFileHandler)
    # ----- end:add root logger
    # +++++ beg:add specific logger
    if sLogger is not None:
        oLog=logGet(sLogger)
        return oLog
    else:
        return None
    # ----- end:add specific logger

def logGet(sLogger,iLevel=logging.DEBUG):
    """get logger
    ### parameter
        sLogger ... logging name
        iLevel  ... logging level
    """
    global lngFileHandler
    if iVerbose>0:
        print('logGet:%s'%(sLogger))
        print('lngFileHandler:%r'%(lngFileHandler))
    oLog=logging.getLogger(sLogger)
    oLog.setLevel(iLevel)
    #if lngFileHandler is not None:
    #    oLog.addHandler(lngFileHandler)
    return oLog

class ldmUtilLog:
    def __init__(self,sLogger='',iLv=0,iLevel=None,iVerbose=0,sOrg=None):
        """constructor
        ### parameter
            sLogger     ... log origin
            iLv         ... trivial logging level
                0       ... debug
                1       ... info
                2       ... warning
                3       ... error
                4       ... critical
                x       ... debug
            iLevel      ... logging level
            iVerbose    ... higher values add more logs
        """
        self.iVerbose=iVerbose
        if iLevel is None:
            if iLv==0:
                iLevel=logging.DEBUG
            elif iLv==1:
                iLevel=logging.INFO
            elif iLv==2:
                iLevel=logging.WARNING
            elif iLv==3:
                iLevel=logging.ERROR
            elif iLv==4:
                iLevel=logging.CRITICAL
            else:
                iLevel=logging.DEBUG
        self.oLog=logGet(sLogger,iLevel)
        self.iIsDbg=0
        if iLevel==logging.DEBUG:
            self.iIsDbg=1
        if sOrg:
            self.sOrg=sOrg
        else:
            self.sOrg=sLogger
    def logDbg(self,sMsg,*args):
        """log debugging data
        ### parameter
            sMsg    ... message
            args    ... arguments for mmessage
        """
        if self.oLog is not None:
            if len(args)==0:
                self.oLog.debug(sMsg)
            else:
                self.oLog.debug(sMsg%args)
    def logInf(self,sMsg,*args):
        """log information data
        ### parameter
            sMsg    ... message
            args    ... arguments for mmessage
        """
        if self.oLog is not None:
            if len(args)==0:
                self.oLog.info(sMsg)
            else:
                self.oLog.info(sMsg%args)
    def logWrn(self,sMsg,*args):
        """log warning data
        ### parameter
            sMsg    ... message
            args    ... arguments for mmessage
        """
        if self.oLog is not None:
            if len(args)==0:
                self.oLog.warning(sMsg)
            else:
                self.oLog.warn(sMsg%args)
    def logErr(self,sMsg,*args):
        """log error data
        ### parameter
            sMsg    ... message
            args    ... arguments for mmessage
        """
        if self.oLog is not None:
            if len(args)==0:
                self.oLog.error(sMsg)
            else:
                self.oLog.error(sMsg%args)
    def logCri(self,sMsg,*args):
        """log critical data
        ### parameter
            sMsg    ... message
            args    ... arguments for mmessage
        """
        if self.oLog is not None:
            if len(args)==0:
                self.oLog.critical(sMsg)
            else:
                self.oLog.critical(sMsg%args)
    def log(self,sMsg,*args,iLv=0):
        """log data
        ### parameter
            sMsg    ... message
            args    ... arguments for mmessage
            iLv     ... trivial logging level
                0   ... debug
                1   ... info
                2   ... warning
                3   ... error
                4   ... critical
                x   ... debug
        """
        if iLv==0:
            self.logDbg(sMsg,*args)
        elif iLv==1:
            self.logInf(sMsg,*args)
        elif iLv==2:
            self.logWrn(sMsg,*args)
        elif iLv==3:
            self.logErr(sMsg,*args)
        elif iLv==4:
            self.logCri(sMsg,*args)
        else:
            self.logDbg(sMsg,*args)
    def logTB(self):
        self.oLog.error(traceback.format_exc())
    def GetVerbose(self,iVerbose=-1):
        """get verbose level 
        ### parameter
        ### return
            True    ... object verbose >= iVerbose
            False   ... object verbose < iVerbose
            number  ... object verbose if iVerbose < 0
        """
        if iVerbose>=0:
            if self.iVerbose>=iVerbose:
                return True
            else:
                return False
        else:
            return self.iVerbose
    def GetVerboseDbg(self,iVerbose=-1):
        """get verbose level in debugging mode
        ### parameter
        ### return
            True    ... object verbose >= iVerbose
            False   ... object verbose < iVerbose
                    ... log level not in debugging
            number  ... object verbose if iVerbose < 0
        """
        if self.iIsDbg>0:
            return self.GetVerbose(iVerbose=iVerbose)
        else:
            return False



#----------------------------------------------------------------------------
# Name:         lmdGUI.py
# Purpose:      OS class
#
# Author:       Walter Obweger
#
# Created:      20200403
# CVS-ID:       $Id$
# Copyright:    Walter Obweger
# Licence:      MIT
#----------------------------------------------------------------------------

import sys
import os
import wx
import logging
import traceback

def getDN(sDN,oGui,sTitle,oLog=None):
    """get SHA limited
    ### parameter
        sDN     ... directory name
        oGui    ... GUI parent object
        sTitle  ... dialog title
        oLog    ... logging object
    ### return
        code
            >0  ... okay content read
            =0  ... okay no data
            <0  ... error
        directory
    """
    try:
        # +++++ beg:initialize
        iRet=0
        sRetDN=None
        # ----- end:initialize
        # +++++ beg:start directory
        if sDN is None:
            sDN=os.getcwd()
        else:
            if sDN in ['.','./','.\\']:
                sDN=os.getcwd()
        # ----- end:start directory
        # +++++ beg:show dialog
        dlgDN = wx.DirDialog(oGui, sTitle,
                        defaultPath=sDN,
                        style=wx.DD_DEFAULT_STYLE
                        #| wx.DD_DIR_MUST_EXIST
                        #| wx.DD_CHANGE_DIR
                        )
        if dlgDN.ShowModal() == wx.ID_OK:
            sRetDN=dlgDN.GetPath()
            iRet=1
            if oLog is not None:
                oLog.debug('ldmGUI::getDN sRetDN:%r'%(sRetDN))
        dlgDN.Destroy()
        # ----- end:show dialog
        return iRet,sRetDN
    except:
        if oLog is not None:
            oLog.error(traceback.format_exc())
        return -1,None
def getFN(sFN,oGui,sTitle,lWildCard=["All files (*.*)|*.*"],iOpen=1,oLog=None):
    """get file name
    ### parameter
        sFN     ... file name
        oGui    ... GUI parent object
        sTitle  ... dialog title
        oLog    ... logging object
    ### return
        code
            >0  ... okay content read
            =0  ... okay no data
            <0  ... error
        directory
    """
    try:
        # +++++ beg:initialize
        iRet=0
        sRetFN=None
        # ----- end:initialize
        # +++++ beg:start directory
        if sFN is None:
            sTmpDN=os.getcwd()
            sTmpFN=''
        else:
            #if sFN in ['.','./','.\\']:
            #    sDN=os.getcwd()
            sTmpDN,sTmpFN=os.path.split(sFN)
            if sTmpDN in ['','.','./','.\\']:
                sTmpDN=os.getcwd()
            
        # ----- end:start directory
        # +++++ beg:show dialog
        iStyle=wx.FD_DEFAULT_STYLE
        if iOpen==0:
            iStyle|=wx.FD_SAVE
        elif iOpen==1:
            iStyle|=wx.FD_OPEN
        elif iOpen>1:
            iStyle|=wx.FD_OPEN
            iStyle|=wx.FD_MULTIPLE
        else:
            iStyle|=wx.FD_OPEN
        dlgFN = wx.FileDialog(oGui, sTitle,
                        defaultDir=sTmpDN,
                        defaultFile=sTmpFN,
                        wildcard='|'.join(lWildCard),
                        style=iStyle)
        if dlgFN.ShowModal() == wx.ID_OK:
            if iOpen>1:
                oRetFN=dlgFN.GetPaths()
            else:
                oRetFN=dlgFN.GetPath()
            iRet=1
            if oLog is not None:
                oLog.logDbg('ldmGUI::getDN oRetFN:%r',oRetFN)
        dlgFN.Destroy()
        # ----- end:show dialog
        return iRet,oRetFN
    except:
        if oLog is not None:
            oLog.logTB()
        return -1,None
def getSplitFN(sFN):
    try:
        sTmpDN,sTmpFN=os.path.split(sFN)
        sDN=sTmpDN.replace('\\','/')
        return sDN,sTmpFN
    except:
        return None,None



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
#
#----------------------------------------------------------------------------
# Name:         ldmWidApp.py
# Purpose:      ldmWidApp.py
#               GUI for ldmWidApp
# Author:       Walter Obweger
#
# Created:      20200405
# CVS-ID:       $Id$
# Copyright:    (c) 2020 by Walter Obweger
# Licence:      MIT
#----------------------------------------------------------------------------

import os
import logging
import traceback

import wx
import wx.aui
import wx.html
import wx.grid

#import wx.lib.agw.aui as aui
#from wx.lib.agw.aui import aui_switcherdialog as ASD

from lindworm import __version__
from lindworm.ldmArg import ldmArg
from lindworm.ldmWidFrmAui import ldmWidFrmAui

class ldmWidApp(wx.App):
    def __init__(self,
                redirect=False,
                filename=None,
                useBestVisual=False,
                clearSigInt=True,
                title="lindworm center",
                oArg=None,
                clsFrm=None,
                kwargs=None):
        """constructor
        ### parameter
            redirect        ... see wx.App.__init__ help
            filename        ... see wx.App.__init__ help
            useBestVisual   ... see wx.App.__init__ help
            clearSigInt     ... see wx.App.__init__ help
            title           ... title of main frame
            oArg            ... command line argument object
            clsFrm          ... main frame class 
            kwargs          ... keyword arguments for main frame object constructor
        """
        self.sTitle=title
        self.oArg=oArg
        self.clsFrm=clsFrm
        if kwargs is None:
            self.kwargs={}
        else:
            self.kwargs=kwargs
        wx.App.__init__(self,redirect=redirect,
                    filename=filename,
                    useBestVisual=useBestVisual,
                    clearSigInt=clearSigInt)
    def getCfgFN(self,oArg=None):
        """get configuration file name
        ### parameter
            oArg    ... object assumed to hold arguments
        ### return
            filename .. okay
            None    ... error
        """
        try:
            if oArg is not None:
                sCfgFN=oArg.sCfgFN
                return sCfgFN
        except:
            pass
        return None
    def OnInit(self):
        """
        ### parameter
        ### return
            True  ... okay processing done
            False ... okay nop
        """
        # +++++ beg:
        sCfgFN=self.getCfgFN(oArg=self.oArg)
        # ----- end:
        # +++++ beg:
        if self.clsFrm is None:
            self.frmAui = ldmWidFrmAui(iLv=0,
                        sLogger='frmAui',
                        title=self.sTitle,
                        oArg=self.oArg,
                        sCfgFN=sCfgFN,
                        ldmCfg=None)
        else:
            self.frmAui = self.clsFrm(iLv=0,
                        sLogger='frmAui',
                        title=self.sTitle,
                        oArg=self.oArg,
                        sCfgFN=sCfgFN,
                        ldmCfg=None,
                        **self.kwargs)
        # ----- end:
        # +++++ beg:
        self.SetTopWindow(self.frmAui.GetWid())
        self.frmAui.GetWid().Show()
        # ----- end:
        return True

# end of class ldmWidApp

def main(args=None,clsFrm=None,**kwargs):
    # +++++ beg:
    # ----- end:
    
    # +++++ beg:init
    iRet=0
    iVerbose=5                                          # 20190624 wro:set default verbose level
    # ----- end:init
    # +++++ beg:define CLI arguments
    usage = "usage: %prog [options]"
    oArg=ldmArg(sUsage=usage,sVer=__version__,iVerbose=0)
    oArg.addOpt('sCfgFN',
            sDft='ldmStorageFolderCfg.json',
            sHlp='configuration file',
            sVerbose='config FN',
            sMeta='pyGatherMDCfg.json')
    oArg.addOpt('sSrcDN',
            sDft='./',
            sHlp='source folder',
            sVerbose='source DN',
            sMeta='path/to/folder/to/read')
    oArg.addOpt('sBldDN',
            sDft='./',
            sHlp='build directory',
            sVerbose='build DN',
            sMeta='path/to/output/folder')
    oArg.addOpt('sBldFN',
            sDft='./',
            sHlp='build directory',
            sVerbose='build FN',
            sMeta='path/to/output/folder')
    oArg.addOpt('sSource',
            sDft='',
            sHlp='source filter',
            sVerbose='source',
            sMeta='ldm*.md')
    oArg.addOpt('sSizeInt',
            sDft='5',
            sHlp='size boundary;-1 <= x <= 16',
            sVerbose='limit',
            sMeta='full')
    oArg.addOpt('sSelLmtChc',
            sDft='half',
            sHlp='select limit;off|half|full|deep',
            sVerbose='limit',
            sMeta='full')
    oArg.addOpt('sLogFN',
            sDft='./log/ldmStorageFolder.log',
            sHlp='log filename',
            sVerbose='log FN',
            sMeta='./log/ldmStorageFolder.log')
    # ----- end:define CLI arguments
    # +++++ beg:parse command line
    iRet=oArg.prcParse(args)
    # ----- end:parse command line
    # +++++ beg:prepare logging
    if oArg.sLogFN is not None:
        import lindworm.logUtil as logUtil
        logUtil.logInit(oArg.sLogFN,iLevel=logging.DEBUG)
    # ----- end:prepare logging
    # +++++ beg:
    app = ldmWidApp(0,oArg=oArg,clsFrm=clsFrm,kwargs=kwargs)
    app.MainLoop()
    iRet+=1
    # ----- end:
    return iRet

if __name__ == "__main__":
    # +++++ beg:call entry point
    main(args=None)
    # ----- end:call entry point



#----------------------------------------------------------------------
# This file was generated by encode_bitmaps.py
#
from wx.lib.embeddedimage import PyEmbeddedImage

BtnGn00 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAACadJ'
    b'REFUWIVtl/uPXddVxz9r7/O6d16eGY8947EnfsaQkiqACOkPEBQhiKqKCqTkP2iaAKGR07T8'
    b'VvETwo6jIDWEAr+jgITUgioEUgNCAilV1agRgSZpiJ3ijOdxZ+bOfZxz9t5r8cO9HjsJR1o6'
    b'j33O/n73Wt+11j4izmOa+NjxDQp6VKUrl6Sbr5fWub/Is894cxdNdEPNLRs6Z0YBIEIruEMR'
    b'3RVzN1X0vRCat2oN71rT3mq06bFEzR/R3gsjzpN9ChygxwKBC02uF7qaXThxbHnj7PKZ9YXO'
    b'7EnnWBJkJqoWYNl0KjLnZwy1kIzDelB+sPPhwq392xujqD8h8BN6vA9s3wtjmsg+BvwEnlVm'
    b'oHog7+aPdYvql+a7cw+cWV5f/PmzD2Ybiyf9XKdyuc+dgZipTDzgcoGqTWF+fzhavbm3eTmh'
    b'sYlhL5f8P4dh/EZM8XWerRs2GfK3HK36XgLC8fI+XPzsYnf+4fWl1UdW5pYvnVhYOnXf0ml3'
    b'dnmdpdl58lxwDhTFMAwQEIdQpNxnvsQ7jxc4Mbc4u9Xvua1+r7y1t1nsHYZFjmdvQfM/gAH4'
    b'I/BnmSPyuazofPHM8fVf+dn1C5cf3Li8+Isbn3HnVzZkvjODOGWUxgzTgEEcMpraOI6pU0NS'
    b'Jfc5c9UMawsrnFpYsaqsuogsj9t65WA0XNDYHvA5u8UbEz14niLnoZnjlP7njs8vPHp65fSv'
    b'Xl49d/6BtYsL60sns5mZSiQzGqsZ64iRDhnrmNYaGm1oLRC0JVggWCARSRLBJ8QjZVb5ynWq'
    b'ROoaVkEcjpMN+IWi4fthmFHSYdycy7POY6tLa49cXDt35vLJ890LJ07jC2E/9GjaBsMmbjdF'
    b'TUHAbBIEm8Zh4kqHIDiBgorFzgrnVs4QLM7g2fCOXz7YvNHGVCvfoJdRVItO0/lOXj28Mn/8'
    b'4oWVs3MnFpczzSO1NQzSgEababxtol6zewhMz2KTsx3pgsI1iGSUvivLCwvZOd2YPxj0L3V3'
    b'N5tB2dzQ3uw7WSX5KbrZ+Zmq88BSd/HEmcU1X1SO2+0WjdWoJpIpMJ38CFg/RkC5C36HaJ1a'
    b'BmFEJRVL5QnWFlfcje1jJ2fKDiG1b8aoq1me5ffPd+fPnlo+uXxsfra0PFojkZEOCdogyMTF'
    b'UwDlLoGXn//roxT6vWtPfozAhJiimmhdQ5l1yFzp5ma71fry2rL3+cbWYPty5n3+4Pri2vql'
    b'1bNubr6iF7eBiFo7nUrvmXRC4A7wsy8+OdWA8coLfwPA01d/5x4iiokRCOy0W/iUMTNXcvHU'
    b'eeddvrZ72HsoE+NSWZQnF2ZnnS+EgfXFJcWJHMV5mrKA8fKV1/jKi09MQ6HTMeOZa7+NmfHn'
    b'X/s7vvwnXzzyGBhqibFFnGXSqWZZ1Dm3tV+tmNllFzWebmy8FF3jg7Q0OiZoi5KAuwBgvPT8'
    b'azx3/YnpvX5qHIynr/4W3/r6t6dj6Z73EkYEl8AH31qzZNh9LllaGaXxbF8P5VAHjFNNay3J'
    b'ImaKE8MJXL/yGl996Ynp/eTZxOxT9szVL/AXX/+Hu+OAYCCJljFDO5SxjmaT2oksWZrth37x'
    b'UbvlFooOHe/BFZOPXY6XDOcmSe7cJL3M7q75jg/kjvCEqWjBOzAEtQmJkCKDVNMLI3fY9kuT'
    b'NOeSaTkIw2yn3pHddpeD0GcQhoxjTTsNxR9/5TX+8E+fxIkc2aTg3DWHx4nDiyNzwh9c/wKv'
    b'vvBdnBhCIlqg0ZrDeEg/HMgwjbwpZaamNKlhv90n1jVNXhFtBpjFiZFNV2+mINNrBDWH3tHm'
    b'VKQOxUmaijcdPQsERqlmEMcMUs04jYkWJt3QTJuosRilcS4hiZNE7oTSeXLnyKcEgraIuCnc'
    b'JKqCu9sPARHBiUPEMO6QTUSLtNowTjXj2NBoa9E0mWnjEBuopjrFpJomdT5apJ5+MIojnrr6'
    b'GC9d+Q5jHTJOQ4LWQMS7NFkxYWrpiNi15/6eKy//JolE0Eg0RVFiSrRtUjNrwB1mZrJtyrI1'
    b'Nk8FbiIzFCVZJFjEmzvyAgY4yCVHEBCdKHwaiGQ6LV1HEZsIUhwejyWIQS1FHYjolkPkp5bo'
    b'WUMiCA6Pd55MPF48XhxO4EtXH+UvX/hXDCVN7Q7QXSUojdZcf+7bXHn5ccCROU/pcypfULkC'
    b'CY40Tsmi9QxuONTetSC3tUZphcy8FS6jcDmFzylcjhePIHzp6qP81df+DUxQU5Il9J76r5Z4'
    b'5fl/5Klrv0bQSDLDi6dwOaUryDQzbYx2lDQ2ug38OEPlLav1WBSnzAiZZpRS0PEFHV9S+hLB'
    b'iBYBx1NXf4NvvfBPAPz+9c8f7Uu/+dXvAPDMi7+OmtJqwpkdLSSoQRTaYWLUD9qOwkfm7M0M'
    b'4x1rOZOc7caR5qm2nMpJXuQUriB3GWaJIIbpRGBPX/08IolvPv/dI/c/c+1xRCapJ0w8ZCgO'
    b'wdQR6sRoFGw8CG0zSrux1Zt4fpwRuIXY+5rs7Xoc3f7uaHVWKudKR1E5vAhJJiXPSCgNkOHw'
    b'fPna45hFgIke1GO0IIp3jsJlFJJTh8j+3ojN7b10OGi2YtC3Ud7Dyk3PI9GIZYa3jmFzJJZK'
    b'lxdzZUfKLJPMCSKTVnK07RKHI8dwmAQQQygQPCJpsh1zGV49qTUODsZ2c2sn/e927/BwUP9X'
    b'CPrvBPkBfvS+5yGUWDYU4VCVjiqrwKxGK5yJdFxOnmVk3pNlOZ4KLxVeCkQcZuAkJ5OCwhd0'
    b'84zK52QxoxlFNncPuHl7h5/u9Ib7/eGNum5fV+I/E7L3eDUceH6A8sMw4mHdI/kqqS4G1TKk'
    b'mEvCF5JL5pw4JzhySCVOM5xNwFEQdTj1eHMUOCQY9TCwszfQD2/vhg93d/q9g8EHwzq8qcFe'
    b'h/AfvBp6gPkjFb1By0MzLXncM2MUo2VtStWobueGdSOhScQmoY1Bq0hIEBLSKtYq1kTaccvg'
    b'cMh274Abt3e4cXvbNg/2N/cG9dujtv0XVf0esfMjXmlu32kg9/4ZGXv9DyjZTlrtjjU0bQh1'
    b'fzhKe8Pu4mCwkC12u362qF0ny1yWT8rURIBqmszGMeqoHevecJA+6vdjb3C414b0djS+b8m+'
    b'B+0P2WmHR93rqIt88vjd7iroRSRdktxdminKM8e63VOdrDieZ34xx83gXeUQLwiKJszqpDoM'
    b'GveGIewcDIe3+vX4QxLvYv5dcO/xZ6PNT0Jl/+/v+fZom1X2KGbesdieGoX2Z8b98FlB7hfk'
    b'PjM7LhP1FZMctBaRPiI7ht0Q5J1k6UcI/01V3KIdHrBJ/CS4OM//AZf78O1wfGMmAAAAAElF'
    b'TkSuQmCC')

#----------------------------------------------------------------------
BtnGn01 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAACTFJ'
    b'REFUWIWNl1uPpcdVhp9VVd9h7z5Nd0/P9EzPtOfoAQdHBoRxkAApF9xyEw6/gAukSITkjgsr'
    b'P8CRwin8B0SEEDcRUgw3RHIUxYoVQ2zHeMZh3NPH6d17f6eqWouLvWemZwIo9WmptEu11/vW'
    b'OtUqEecxzTw33qTkmLpy1YaMi53KRi+XRficN3fHRHfV3KahK2aUACIMgjsT0SMx90BFP4qx'
    b'f6/T+KH1w8Ne+2M26Pg6w3kYcZ7wc+AAx6wRud0Xenus4falC5u7Nzav76yNli87x4YgS0m1'
    b'BAsLVQTnlwy1mI2zblp9cvjp2sPHj3abpD8l8lOO+Rg4OA9jmgnPAf8Bnm2WoH6lGBdfHJf1'
    b'b6yOV165vrmz/qs3Xg2765f9yqh2hS+cgZipzC3gCoF6yHH18azZfnCydy+jqU/xpJDix7PY'
    b'vpNyepsvdz17zPh7np76PAHhYvUSLn1+fbz6+s7G9htbK5t3L61tXH1p45q7sbnDxvIqRSE4'
    b'B4piGAYIiEMoc+GDr/DO4wUurawv70+O3f7kuHp4sleenMV1Lob3oP8vwAD8U/Avs0LiC6Ec'
    b'/f71izu//cs7t++9untv/dd3P+dube3K6mgJcUqTW2Z5yjTNaBbSppYu92RVCl+wUi9xZW2L'
    b'q2tbVlf1GJHNdui2TpvZmqbhlC/YQ96Zx4PnTyh4bekilf+Vi6trv3tt69rv3Nu+eeuVK3fW'
    b'djYuh6WlWiQYvXW02tDojFZbBuvptWewSNSBaJFokUwiSwKfEY9Uofa1G9WZPDashjRrs035'
    b'tbLn+3EWqBjR9jeLMPri9saVN+5cuXn93uVb49uXruFL4XE8ph96DJub3RQ1BQGzuRNs4Ye5'
    b'KR2C4ARKatZHW9zcuk60tIRn1zt+83Tv/pByp7zJcaCs153mW6Oifn1r9eKd21s3Vi6tbwYt'
    b'Ep31TPOUXvuFv20evWbnCCxmsflsT+OC0vWIBCo/ls21tXBTd1dPp5O746O9flr19/V4+YNQ'
    b'S3GVcbi1VI9e2RivX7q+fsWXtePRsE9vHaqZbAoslD8F1ucIKM/AnxDt8sA0NtRSs1Fd4sr6'
    b'lrt/cOHyUjUi5uHdlHQ7FKF4eXW8euPq5uXNC6vLlRXJekk0OiNqjyBzEy8AlF+MwHxdUc0M'
    b'rqcKI4Kr3MryuN7ZvLLpfbG7Pz24F7wvXt1Zv7Jzd/uGW1mtOU4HQEJtWKjSc0oXBP7f75xr'
    b'UEyMSORw2MfnwNJKxZ2rt5x3xZWjs+PXghh3q7K6vLa87HwpTG0iLitO5KmfFyk7n20hsvj9'
    b'HL1z+xYWAUMt01rCWZBRvcy6rrj9x/WWmd0LSdO13tqN5HofxZO0JSAUPuCehPYLip+X/2vd'
    b'AH3u/wbgMnj1g/Ubhr3ksuWtJrfLEz2TM53S5o7BBrIlzBQnhhMWYudkvvbXX/v2C+sv7jEc'
    b'IBhIZqBlZmfSarOc1S65bHl5Eif1Z8O+O4onNLmj18igA2oJwfAO3EL8ExH45le/DcBffe0f'
    b'8WJ4ebbv2d556Q4OjMQ0n7If993ZMKlM8orLptU0zsJhdyhHwxGnccI0zmhTNydBxjAEw4k8'
    b'lbe+8g8AfOPv3gTgL7/6TzhxeHEEJwSROSExhEyySK8dZ+mMSTyVWW68KZXnt8JfyMgcy9kn'
    b'FyVbBBQvLJS5eUDyrNoZwhu/9yrf+86P+c4//xsAf/bWH+KQZ9YSQ8QwU5JFZrnlLM2Y5oZp'
    b'13L6uMnNaVRnpn3SlJrc2izOmKUZs9TQpJY2t3S5o9eeqANJI0kj2TJgfOWtP16A/xEgiMjC'
    b'CoIXwYlhZJIlBu1pc0ebenodLJlmM+0DYlPVPM5JKs3q1JRkiU57yuwJAmoZ7xwiAgZeCgqp'
    b'8c7z59/4Emrx3K3u5veBZDJKJhM1kUxRlJQzw5DVzHpwZ8FMDkzZtN5WqVmk3vziyZaIlvDm'
    b'UJWnBHBQSIEgIDqP8EWaZZt3Cl6MJ56DuTs9HsuQolpOOhXR/YDIzyybWM9lohQOj3eeIB4v'
    b'Hi8OJ8xL8iK/5yd7BvxkGMqgA5CpvEfEEZyn8gUZI7qMxJbc5mzJjg3uB9Q+tCildtxjEIJ5'
    b'K12Q0hWUvqB0BV7c09piODBBbW5ezhUrtXm0m2WcGN4FvHhKV5ANWo2mvcnQZE29HgA/Cai8'
    b'Z51eSOKUJSFooJKSkS8Z+YrKVwhGsgQ4HAWCR22ens/60gwkHILiGDTjzHhykKgGSRhmmWYS'
    b'dWjiZ+bs3YDxgQ1cz86OUqNF7qygdlKUBaUrKVzALBPFMBVkUdcUBctPnSCmiCiy+NQUQ3EI'
    b'po7YZZomWjuNQ9/kozToAzw/CUQeIvaxZnu/a5N7fNRsL0vtXOUo63lKZZmX9bn3eyDg8Iub'
    b'b97qi3hQjzGAKN45ShcopaCLiccnDXsHJ/ls2u+nqO+jfIRVe543kpGqgLeRYStkNipXlCvV'
    b'SKoQJDhBBDL2rO2SuSsMh0kEMYQSwSOS5+2YC3j15ME4PW3twf5h/u+D47OzafcfMeq/E+UH'
    b'+OZjz2soqeop45kqI1W2gWVNVjoTGbmCIgSC94RQ4KnxUuOlRMRhBk4KgpSUvmRcBGpfEFKg'
    b'bxJ7R6c8eHTIzw6PZ48ns/tdN7ytpH8hho/4Vjz1/ADlh7HhdT0h+zqrrkfVKuZUSMaXUkhw'
    b'TpwTHAXkCqcBZ3NwFEQdTj3eHCUOiUY3ixyeTPXTR0fx06PDyfHp9JNZF9/VaG9D/B7fiseA'
    b'PXkXwDsMvLY0UKQTM5qULAw51003rMy6XmKfSX1Ge4NBkZghZmRQbFCsTwztwPRsxsHxKfcf'
    b'HXL/0YHtnT7eO5l27zfD8K+q+l3S6Ef8Tf/oSXtw/mVknEw+oeIga33UauyHGLvJrMkns/H6'
    b'dLoW1sdjv1x2bhSCC8W8TAEoaprN2pS0GVo9mU3zZ5NJOp6enQwxv5+M71u278LwQw6HGc86'
    b'Gc4Vy3PjT8fboHeQfFcKd3eprK5fGI+vjkJ5sQh+vcAt4V3tEC/zlMyYdVl1FjWdzGI8PJ3N'
    b'Hk669lMyH2L+Q3Af8bfN3otQ4X99nh80B2xzQrn0gaXhahOHX2on8fOCvCzIS2Z2UebRVwKg'
    b'NiAyQeTQsPuCfJAt/wjhP6nLhwyzU/ZIL4KL8/wPkLnppTGdsd8AAAAASUVORK5CYII=')

#----------------------------------------------------------------------
BtnGn02 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAACPRJ'
    b'REFUWIWVl12MZMdVx3+n6t7bPd0zO+6end3ZHe96vfZ6FxtDLFgHKQLxAlJEREjEQ5Q8oEhB'
    b'IomS2CQ4SCgCPyCh2E5CkGN4QnlBiCCwxBuRIHlBkCWSEwvnE5TdmHg/Znpmuvv2/aiqc3i4'
    b'vbOzxI7hlo7OrVt17/mfU6f+p66I87zZdeyp8fuLPHvEm3vQRM+quQ1D18woAERoBTcT0V0x'
    b'd01Fvx9C8/LBpw+++Gbfzn7SoH3YvW8wGD5wYn3j7LmNM9vrK6snnWMsyDCqFmDL94XM+aGh'
    b'FpIxq+e9H+z8cL39hJ5dlOV/ygv6V/9vANkTg6cHRf/yscHaw2c2tkePnXs0Ozs66ddW+i73'
    b'uTMQM5UuAi4X6LcpHNsvF1vX9q5fTGhsYtjLJf+P8onqQvpc9fT/CYB9hN8YDTYe3x5v/cLm'
    b'2saFE+vj0/eN73XnNrYZrx4jzwXnQFEMwwABcQhFyn3me3jn8QIn1karN6cTd3M66f3o96//'
    b'8f6f7PzB/7bnRdwd47/Nu7Ji5Z1njm//4k9tP3Dx0bMXRz939hF3fvOsHFsZIk5ZpIoyzZnH'
    b'ksVSqlhRp4akSu5z1vpDTq1vcnp90/q9/gCRjaqtN/d/unxc3xKdfJ1vv24Ejo9Hl4+Pth57'
    b'6OT99186eX7t1HhT+oOclLU0WhG0pdaaYC1KQk27CBg4cWRS07OG3BXk3lOseHfveKvwlo9i'
    b'Sh5gZ//6axP2X/yxCGRPDv7o3OaZtz10+vxDl049sHrh5BnX7+dyEPfYCxNmcco8zalTRZMa'
    b'ggWCdtJqoLUOXJkWzOKMaTygSS3Heuus99YRkcy89UOKfu/R8n771/jVQwDyQffe4crq2x/c'
    b'Onfpke2LG1vj43nRd1JTMY1TqlTRakurLcEiQSNxqYOlpe6ANKmh1mYJMiIiiIh4710meT6t'
    b'5sVkNsnDY23O1+wbGUAx6J0f9lceHg9GJ86MTvmi77jR3qSxGtVEMgUMM8OETqNL3fX19ng3'
    b'E4A6tczDgr70GfdOcGq06a7euufksLdCSO1LNQv82idHvzVaHf3s9vGty/dtnh6cGI9IWSMH'
    b'cZ9WaxRdrnWn01LfzgH9seddSyjRIm2qiURyX4CJzOoyb2PI1Hit/vnWZ97nj26PTm1f2Drn'
    b'1o71mcRbQEStXfqih151vTv3r984EgnFxAgEdtqb+JQxXOvx4Onzzrv81O5s8hYnxoVe0Tu5'
    b'vrrqfCHMbSqLNCdZBNGlyQRoJ5Y6ud1fiqG88NTfHXmWMOvu1QKVliyslKLvGK2tuWG/v2lm'
    b'F13UeG9j1Ti6xge5s9300Ki9gehd4y/83t8D8OdPvXgXiLsAEcEl8MG31owNu88lS5uLVK1O'
    b'dSYznVOlmtZakkXMFCeGE5ZiR+TOs+eXxj/0zK8D8Bef/IcjcwwHCAaSaKkobSaVLlaT2gnv'
    b'3pZ/Kh/6XrbuC82igOKc4AS8CF4c3knHt2KIcEfoePitv3qJf/vHb3Ply98B4MPPvuPIvG6i'
    b'E0iWqFLFTr3PjZ1dJgdT75Jpbx7KbKfekd12l4MwZR5KqljTLpfCMATDiRyK4O6SJ557FwAf'
    b'+8w7yZyQieCXERAS0QKN1h1JhQMp08Kb0svUlCY17Lf7xLqmyftEGwKrODEyJ4jLEVznEmAI'
    b'ag61wyoCwJPP/SZOEgiYJdQgqhIILFLNPFbMU02VKqIFAJyZNlFjXKTKylBSxpIyLljEiipV'
    b'1Kmm0YagLVEDUQPPPPGlJQxZAhBAEBGcuOXSCU4MI3V8oA1VqqliQ6OtRdNkpo1DbK6a6hST'
    b'aurIJFqkXr6wiAuqWFHpgkpLnnuyqyOf+d2/wbvUeUxYSuqA4HACiJJIS+ruCCqmRNsmNbMG'
    b'3MyZyS1T5taYkcAhSwpRksWO+y0QtOULH/9yl+3P/goAzz75JZCEiCJLzkgWibbMm9sBgi6Z'
    b'8ViCGNRS1LmI3nSIvGqJiTUkguDweOfJxOPF46XzRhA+8MwvAfCFT3RAPv7Zd3P0MpRGa+q0'
    b'IFoEHJnz9HxO3xf0XYEER6pSsmgTg6sOte9ZkBtao7RCZt4Kl1G4nMLnFC7Hi0cQxIQPfPqX'
    b'AfjIc79GsoQeKUBqXbZ3ZTqSzPDiKVxOzxVkmpk2RrtIGhu9BXwnQ+Vlq/WeKE4ZCplm9KRg'
    b'xRes+B4930OwQ48cOb/zzNvRZZjvnEsTEHEIiqPVhDM7dCSoQRTaMrGYBm0X4TVz9pKTz4cv'
    b'WssPUmO7caFNqs1oHTk5hSvIXYYXh4lhBpgDE9SMpF2GR4sk7aqjLJuZdUyKIOoJdWKxCFbN'
    b'Q9Ms0m5s9Zp8Nv1tB9/svzTZK3UV3f7uYmtV+s71HEW/21JJlnWIhNIAGQ6/rHxtFwDxoB6j'
    b'BVG8cxQuo5CcOkT29xZcv7WXZvPmZgz6Csr3u+QUh/y7vWyPuwuGrZEY91xerPVWpJdlkjlB'
    b'pCslt7e9SLcUhsMkgBhCgeARSTiBwmV49aTWODio7NrNnfTftyaz2bz+Vgj6L/J8/NwhAAD5'
    b'mn5FL8slVbaAVY1WOBNZcTl5lpF5T5blePp46eOlQMRhBk5yMikofMEgz+j7nCxmNIvI9d0D'
    b'rt3Y4dWdSbk/La/WdfvP9mfhU7d3zl2nYgt2pdFw70RKVHWbZKu5ZtlYzfWGGT4rEL3tqWCA'
    b'03zJhQ5xgrcMUqQqW3b3S3315iS+urc7n0zLa2UdXrJgV47Qw93/BXLFvmVvFTFjEaNlbUr9'
    b'Rd2ulXUjoUnEJqGNQatISBAS0irWKtZE2qplPiu5NTng6o0drt64ZdcP9q/vzetXFm37FVX9'
    b'J3k+vXjUaXnDn9OPFk97x+Venj18z3AwOrG2no0GA79arLiVLHNZ3tEUdGceTWZVjLpoK90r'
    b'5+m16TRO5rO9NqRXonGFz7d/+Hpm3hgAYB9075fcXRgWvTP3DAanV7LieJ75UY4b4l3fIV4Q'
    b'FE2Y1Um1DBr3yhB2DsryR9O6+iGJ78kL+pdvZOMnAjic9LH8PSLyM4I8JMh9ZnZczI7hpABA'
    b'rUVkisiOYVcF+W6y9E370/DXb/bt/wHME7nLZM/j7gAAAABJRU5ErkJggg==')

#----------------------------------------------------------------------
BtnGn03 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAACVdJ'
    b'REFUWIWVl2uMXddVx39r73POPXPvXI/vjMcee2LHdmo7DwKE4BQJoVaCKOVDm4ZPCIRQJUop'
    b'UYmTNCkSQpAPSCRxk5AQFZAQ6hfUqqGYFhEeUmmFhFBdpEKFS0lBtRtqezzP+zqvvdfiw7kz'
    b'cUrTwL1aWufstc/e/732Wv+1t4jzvN1v35OLH8jS5C5v7h0mekzNLRnaNyMDEKEW3EhEN8Tc'
    b'FRX9ZtNUX9t5ZueTbzd28v2M9rD7+W63d9vBhaVjx5eOri7MzR9yjkVBekE1A5t9LyTO9wy1'
    b'Jhqjctz51vq3F+qP6rHpZPKf8gn90/83gORc96lulp/d1+3feXRpdXDP8buTY4NDvj+Xu9Sn'
    b'zkDMVFoPuFQgr2Ozb3syXbmyde1MREMVmq1U0n+bnCtOxReKp/5PAOwjvH/QXbpvdXHlx5b7'
    b'S6cOLiweuXXxFnd8aZXF+X2kqeAcKIphGCAgDiGLqU98B+88XuBgfzC/Ntx0a8PNznd+/drv'
    b'bP/u+m9893xexL0x+Qd5KMnmHjx6YPUn7li97czdx84M7j12lzu5fEz2zfUQp0xjwSSOGYcJ'
    b'05kUoaCMFVGV1Kf08x6HF5Y5srBseSfvIrJU1OXy9g9M7tMfDk7+mX//nh44sDg4e2Cwcs/p'
    b'QydO3H7oZP/w4rLk3ZSY1FRa0GhNqSWN1SgRNW09YODEkUhJxypSl5F6Tzbn3S2LK5m3dBBi'
    b'9ADr29eubrJ94X95IHm0+9vHl4/++OkjJ0/ffvi2+VOHjro8T2UnbLHVbDIKQ8ZxTBkLqljR'
    b'WEOjrdTaUFsLbhKnjMKIYdihijX7OgssdBYQkcS85U0MfuvuyQn7p/ClPQDyYfdzvbn5n37H'
    b'yvHb71o9s7SyeCDNciclBcMwpIgFtdbUWtNYoNFAmOnG4ky3QKpYUWo1AxkQEUREvPcukTQd'
    b'FuNsc7SZNvfUKV+2f0kAsm7nZC+fu3OxOzh4dHDYZ7njer1GZSWqkWgKGGaGCa1GZ7p91117'
    b'2xOAMtaMmym55Cx2DnJ4sOwu39h/qNeZo4n1V0um+P7HBr84mB/80OqBlbO3Lh/pHlwcEJNK'
    b'dsI2tZYoOtvrVseZ3o0Bvan995/4NPfefwczK8ECdSwJBFKfgYmMyklahyZR42r5o7X33Xft'
    b'+4UTy8duO334xPHB/l6qSU1hY4lWz1aym24zELL7bG9qf/mJzwDwlb+7xL0/deYmm6FiVFpR'
    b'hCnOeell/RCjbt/YXo9OjFOdrHNoYX7e+UwY21CmcUy0ANIODhHQViy2svuO8vITrwDwK8+8'
    b'H4A//NifAxGz1q7WUOiEqU0kyx2Dft/18nzZzM64oOGWyorF4CrfyBvppnuT2luI7tkffvYh'
    b'AP7gyTa7PvT0e2e2m4FGjAAugm98bdWiYbe6aHF5Gov5oY5kpGOKWFJbTbSAmeLEcMJM7CZ5'
    b'c9vD5x8E4Feffe939TEcIBhIpKZgYiMpdDof1Q66aHF+2Azzq/Wa22i2mMaSShtqrVELCIZ3'
    b'4Gbid0VaefFv/hIn4MX4yPn37fV7o29L3YkDIzCOO6w1a25UDzsmse+iaWfcTJL1cl026g12'
    b'miHjZkIRyhYEEcMQDCeyJ4Ljub/+PI++530IDofnpb99FS+OxAmJCH7mASESrKHSsiWpZkcm'
    b'cepN6SRqShUrtuttQllSpTnBesA8TozECeJSBAcibc1AOP/qBc498DOYMYsJePSBB3ESQcAs'
    b'ogZBlYaGaSwZh4JxLCliQbAGAGemVdAQprGwSTNhEiZMwpRpKChiQRlLKq1otObpRz5D0IZo'
    b'kcfe8xCCzBhdAOH5x1/BicOL4EVwYhix5QOtKGJJESoqrS2YRjOtHGJj1VjGEFVjSyrBAuXs'
    b'g2mYUoSC5x77HAAff/QCjZZAwLvYrpiGFx7/NADPnvuzdksEECUSZ9TdklaIkbqOamYVuJEz'
    b'kxumjK0yI4JDoKUcogUaC/zRk18A4IPPvguAlx7/KyBy/tULIJEXHv9suwXPtTzw9COfbeNm'
    b'10GAF4fHYxFCoxaDjkV0Tfho/he+Z0fnBv6OfYO5fLC/Rz/P6SdzzCc5vaRDxyf88ZP/sDfY'
    b'h87/JLnrkkjaMp4Zzz+2V2F5+OP30/EeEaGKDUWomcaaUVVwdXOHtfWdcmej/MZovXrNofaa'
    b'NXJdS5RaSMxb5hIyl5L5lMylePH88jPvBuCXnnk3mLT8bxGdFaBzzz24B64t04FohhdP5lI6'
    b'LiPRxLQy6mnUUOkN4Bued6aHiToQdXd18yxb6Hfp53Myn+b0kpzcd/DiUFN+5P4TODKcJMgu'
    b'z5ugZiiR+x44uZcRbdFqAXjniWpMpzU31keyvj6uqkl9UcW+5OTF5pNW861Y2UaYahVLM2pH'
    b'SkrmMlKX4MVhYm3KmZt5wIjaRniwQNS2Osrsb2YtkyKIepoyMp02VoybqprGjVDrFXk+vtIe'
    b'ycz+S6NdKovgtjemK/OSO9dxZHmbUlFmdYiIUgEJDj87C9RtIooH9Rg1iOKdI3MJmaSUTWB7'
    b'a8q1G1txNK7WQqOXUL7ZBqc45Cv2NbvPnTKsT2Sx49Ks35mTTpJI4gSRtpTspr2Iw5FiOEwa'
    b'EEPIEDwiESeQuQSvnlgbOzuFXVlbj/99Y3M0Gpdfbxr9R3k5vLAHAEC+rF/Us3K7KivAvAbL'
    b'nInMuZQ0SUi8J0lSPDlecrxkiDjMwElKIhmZz+imCblPSUJCNQ1c29jhyvV1Xl/fnGwPJ5fL'
    b'sv57e6n5zd2MedOp2Bq7WGlzy6ZMUNVVos2nmiSLaq7TS/BJhujuSgUDnKYzLnSIE7wlEAPF'
    b'pGZje6Kvr22G17c2xpvDyZVJ2XzVGrt4Ez28+V4gF+3r9k4RM6YhWFLHmE/Luj8pK2mqSKgi'
    b'WhnUijQRmojUitWKVYG6qBmPJtzY3OHy9XUuX79h13a2r22Ny0vTuv6iqn5BXo4Xbl60vOXl'
    b'9Neyp7zjbCdN7tzf6w4O9heSQbfr57M5N5ckLkm9tPef9syj0awIQad1oVuTcbw6HIbN8Wir'
    b'buKlYFzkxfq3vtc0bw0AsA+7D0jqTvWyztH93e6RuSQ7kCZ+kOJ6eJc7xAuCohGzMqpOGg1b'
    b'k6ZZ35lMvjMsi28TeU0+oX/yVnN8XwB7nR5Jf1ZEflCQ04LcamYHxGwfTjIA1GpEhoisG3ZZ'
    b'kP+IFv/Vfq/51NuN/T/UIcpMS2fEYAAAAABJRU5ErkJggg==')

#----------------------------------------------------------------------
BtnGn04 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAACepJ'
    b'REFUWIV1mN+PXddVxz9r73PO/TEzHs/YMx7/jn8lEGhrKhryFKTQpolURQTRJ16hVVvcJnbS'
    b'PiEeeEDEcZMopMkfgEAl4keA8qNBDU+AgqBRIwKN3RDbrT2eH3dm7o9zzzl777V4uNdju4J7'
    b'tbSPls7Z3+9ea5/1XfuIOM9P/+x3UkGPdsu1FqWbH25Z5/4iz37OmzttosfU3D5D58woAERo'
    b'BDcQ0U0xd01Fr4RQv1dpuGx1c6PWuscilfyeb34aK9sF1XTH22OewKk611NdzU4t79137L59'
    b'Rw/Pd2YPOMeiIDNRtQCbPi9kzs8YaiEZg2rY+mjj+vyN7VvHyqg/IvAjenxomtZvQ9xeeHYP'
    b'+OfxrDAD7Qfzbv5ot2h/ak937sGj+w4v/MJ9H8uOLRzwc522y33uDMRMZRIBlwu0mxT2bI/K'
    b'lWtbqw8kNNYxbOWS/+cojN+JKb7NuapmlRFvkEwT4vydCADC/tZxXPz4QnfPQ4cXVx5emtt3'
    b'Znl+8dDxxSPuvn2HWZzdQ54LzoGiGIYBAuIQipT7zLfwzuMFlucWZtf6PbfW77VubK0WW4Ow'
    b'wP7sPaj/B7C7UyCcY44mfiJznSeX9y6fvf/QyWOnDxyfPbXvKHu782Q+Q4mMYkmgJlrEbEJC'
    b'ELx4clq0sg4H9i6ytGcvp5ePcGXj+oHLt67ORI2Lg/FoJcaxcI4NXmEAmOe3LOfszH5a/uf3'
    b'75n/5SNLRx55YOXEyQcPnp4/vHggm5lpi2RGbRVjLSl1xFjHNFZTa01jgaANwQLBAolIkgg+'
    b'IR5pZW3fdp12InUNa0McjZMN+WRR804zymjRYVyfyLPOoyuLBx8+ffDE0QcOnOyeWj6CL4Tt'
    b'0KNuagybhN0UNQUBs0kSbJqHSSgdguAECtosdJY4sXSUYHEGzzHv+KWd1atNTJXyu/QyivaC'
    b'03Syk7cfWtqz//Sppfvmlhf2ZZpHKqsZpiG11tN82+SNMbuLwHQUm4y2uy8oXI1IRst3Zd/8'
    b'fHZCj+3ZGfbPdDdX62Grvqq92Q+ytuSH6GYnZ9qdBxe7C8tHFw76ou241axRW4VqIpkC08l3'
    b'gRUz49KFP+KZF35jsiVvE5oSrVLDMJS0pc1ia5mDC0vu6vreAzOtDiE178aoK77zyOyvLMwu'
    b'fOLw/pVPHV861F1eXCBltezEbRqtUCYht+mYpqOSePHCHwPwr999j1/8zM9O/ZN/QokWaVJF'
    b'JJL7AkxkUI3yJoZMjZtlKjed9/nHDi8cPHz/ykk3t6dNL67Ta9ZRa6ZrSRhpOuUde+nCnwDw'
    b'2y98HoBXn/vT3XvNpkbCxAgENpo11sNNZuZanD500h1ePHjQmz/rxDjTKloH5mdnnS+EofWl'
    b'TEOSRZDJyiEBOjFLYImvXpoA/+GzbwDwpYtPTe+9bQmzybVaYKwjShtJ0XYszM25mXZ7ycwe'
    b'cFHjkdrGi9HVPkhDrWOCNuguqP0/ppx74dcA+MrFp+7x303iHkJEcAl88I3Vi4Ydd8nSUpnG'
    b's30dyECHjFNFYw1pWmicGE6YmuHEePm7b+76vnrpqV3/6//4t7vXd54zHCAYSKJhzMgGMtZy'
    b'Nqktu2Rpth/67ZvNmtsMW5SpotZAow1qEcHwDi4+822cA+/g2SeexAv4XWLgxTj32BM4B87B'
    b'61//Dt6Bd5PSnTkwIsO0w1pYc4Om3zJJcy6ZtoZhlG1UG7LZbLIT+gzDiHGsJiRI/P7Xvg3A'
    b'80+/gRPBiUwLzh1zeJw4vDheffZvAHjtuUlEhES0QK0VgzigH3ZklEpvSsupKXWq2W622ah6'
    b'bNQ9tppthnGSjotP/xkA33jp1wH4g6+9gSGoOZJ5zLKppOQ4Ml4+/yYA51/8HADfevbvUAJl'
    b'KunHAYM0ZJzGRAuTyikXWr1iny+6R7LOTLdwc0WbvcUsi8Uc88UMe/Iurz/31q5kXnjxVzEc'
    b'WIaZ2y06AE4U73SXNMBXXvg0ZarZCSN2mpJhqBmMKr11bVj1ro0qh9hQNVUpJtU0KTLRIpXW'
    b'jFNFGUu+8PyjAHz50mcYpxFBKyDiXcJJAsLUEiB84+XJ23H+pc+SSASNxGmRiinRNEnNrAY3'
    b'cGaybsrQajMSOASmwpMsEiwSLPCbzz8yUT1teOUf3gISgoIkRBQR5Zt//9cki0RLfP3lzyGy'
    b'Gwi8ODweSxCDWoo6FNE1h8iPLdGzmkQQHB7vPJl4vHi8OJyAIFM5Ur742COTkozxzWf+Yhfk'
    b'6cefoNaKKpVEi4Ajc56Wz2n7grYrkOBI45QsWs/gqkPtsgW5pRVKI2TmrXAZhcspfE7hcrx4'
    b'BEFMAA8mqCmXnvlzAF48/5cTajbZ7UEDQSPJDC+ewuW0XEGmmWltNGXSWOs68EOHyntW6U/i'
    b'AKUSMs1oSUHHF3R8i5ZvkcntxsnhKBByXrnwnakWPAnAS+ffRIm3uwEaTdQpAELh88kcUWhG'
    b'ibIftCnDTXP2rsP4wBo+SrVtxlLrVJnROHJyCleQuwwvbqr3gDkw4UsXPzvVgr+aasHjqOkk'
    b'Usi0N9AJIfWEKlGWwcbDUNdl2oyNXkPth47ADcw+1GTvV+O4tr1ZpvFOgwuOQhxeBHGT9U9U'
    b'sUYJGMIXLz4OwBee/zSKkdQTdaKW3jlaPqeQHAvG9lbJ6vpWGgzrtRj0fZQrxNaq5+FoxFaG'
    b't45hcyQWWy4v5lodaWWZZE4QmUjJbtslDkeO4fjkY0dBDKFA8IikSTvmMrx6UmPs7Izt2tpG'
    b'+sl6bzAYVv8Vgv4zQf4dX37oOYsSWzVFGKjSUWUFmNVohTORjsvJs4zMe7Isx9PGSxsvBSIO'
    b'M3CSk0lB4Qu6eUbb52Qxoy4jq5s7XLu1wY83eqPt/uhqVTVvK/EtQnaF18KOl+975T/qkod0'
    b'i+TbSXUhqLZCirkkfCG5ZM6Jc4Ijh9TCaYazCTgKog6nHm+OAocEoxoFNraGev3WZri+udHv'
    b'7Qw/GlXhXQ32NoR/4bXQE+fNizgwg3doODvTkMctM8oYLWtSapdVMzeqagl1ItYJrQ0aRUKC'
    b'kJBGsUaxOtKMG4aDEeu9Ha7e2uDqrXVb3dle3RpW75dN80+q+j1i5we8Wt8CTMTdczIytvof'
    b'0WI9aXtzrKFuQqj6ozJtjboLw+F8ttDt+tmicp0sc1k+KVMw6Xk0mY1j1LIZ69ZomG72+7E3'
    b'HGw1Ib0fjX+zZN+D5vtsNCO4IyBy+5B4z+H0y90V0NNIOiO5OzNTtI7u7XYPdbJif575hRw3'
    b'g3dth3hBUDRhViXVUdC4NQphY2c0utGvxtdJXMb8ZXBX+Fa5ugt89+H0bgeArZfrrLBFMfOB'
    b'xeZQGZqfGffDxwW5X5DjZrZfJruvAECtQaSPyIZhVwX5IFn6AcJ/0y5u0Ix2WCX+X58C/hcB'
    b'ox/AoFOP/AAAAABJRU5ErkJggg==')

#----------------------------------------------------------------------
BtnGn05 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAACZtJ'
    b'REFUWIWVl3+sZVdVxz9r73POve++d+fNe2/e/J7pdMrMlJYSG9KKMfKHFitKpBAajJoYEqyt'
    b'1c4PZooJMdgEIp0f7QzalqAJNiaGBkggKigErP8QpZogDUUFlfkBffPmvfveuz/OPT/2Xss/'
    b'zn1TRinVc/LNzjn7nL2+a521vnsdEed5rWPLo/PvzdLkdm/udSa6X80tGNo1IwMQoRLcQERX'
    b'xdwlFf1uXZcvbpzeePa11k5+3KQ97H6t05m+Zfvswv4DC/v2zE7N7HCOeUGmg2oGNnlfSJyf'
    b'NtTqaAyKYet7K5dnq5O6Px+N/kOe0b/4fxNIjnUe62Ttu7Z0urftW9gzd+eBO5L9czt8d6rt'
    b'Up86AzFTaSLgUoF2Fest66N856W1pSMRDWWo11JJvzU6Nj4Uz48f+z8RsN/lvrnOwt175ne+'
    b'ebG7cGj77Pzum+b3ugMLe5if2UKaCs6BohiGAQLiELKY+sS38M7jBbZ352aW+z233O+1fvB7'
    b'Sx9Z/+jKB/+nPS/iXjH+m7wzyabesW/bnp95/Z5bjtyx/8jcm/bf7g4u7pctU9OIU/I4ZhSH'
    b'DMOIfIJxGFPEkqhK6lO67Wl2zS6ye3bR2q12B5GFcVUsrr9hdLf+RHDyz/zrj4zAtvm5u7bN'
    b'7bzz8I6bb751x8HurvlFaXdSYlJR6phaKwotqK1CiahpEwEDJ45EClpWkrqM1HuyKe/2zu/M'
    b'vKVzIUYPsLK+9HKP9c/9rwgkxzt/cGBx308f3n3w8K27bpk5tGOfa7dT2QhrrNU9BqHPMA4p'
    b'4pgyltRWU2uDSmsqa8iNYs4gDOiHDcpYsaU1y2xrFhFJzFu7jsGv3TG62f4h/P11AvKQ+9Xp'
    b'qZm3vW7ngVtv33NkYef8tjRrOykY0w99xnFMpRWVVnzokWf4qXvfSLBArYHa4mRsiHz46Cd4'
    b'01tfPyEZEBFERLz3LpE07Y+HWW/QS+s7q5Sv2784gKzTOjjdnrptvjO3fd/cLj/VzrhaLbNU'
    b'XiWPOdXE0w8f/RMAPnLsTyljeQOKUHL6+J8BcPbEs4xjSb8ecDm/zJXiIr4l7JpbdHOdrTum'
    b'W1NvaLXahwDczKOzv7HQ3XZg7+Kuha1bZlqWBiklJ9cRRcyprSJa4KPHPwnAiSd+fWLkzwkW'
    b'eOJvnyNY4MLJptQfOn0/AH986lOUWjIKA/pxg5ENCK5y3ZlOe8/CroWF7rb96cmpd8vWD+44'
    b'e3jnwdsP7T7wlsX5bqc70zaSILWVRFPAMAPDOHfiFT155Nx7MGsKcXN8+tRnr88/8Pg7MRQ1'
    b'Q8SRSQsfEytzk/5Gkf/X0uWvffPit/7RiXGolbV2zM7MOJ8JQ+tLHodECyCKoUAElBPn3gPA'
    b'0bP3A3oDDOXB0/cB8FuPvwOImDVzajVjHZHbSLK2Y67bddPt9qKZHXFBw97SxvPBlb6WV8pN'
    b'J0bBAOPc33wWMI6du39yT2+Y38SDp38ZUD7xlS9eJ87ECSOAi+BrX1k5b9hNSbS4mMdxp68D'
    b'qTUBq2iJxxkIHicCwKm3vWvi0STssmlyUw9vHB+85+fR65+oiRESqRhTWJSx5jNRbbuLFmf6'
    b'db/9crXsVus18lhQak2lFWoBwfAOzhx/DufAb0IauAm8WHPtGnz80b+ePNtId+LACAzjBsv1'
    b'shtU/ZZJ7Lpo2hrWo2SlWJHVapWNus+wHjEORUOCyB8efQ6A08c+jRPBiSC4G+DwOHF4cTx1'
    b'8q8AeObUF3BiCJFgNaUWjUjVGzKKuTel5dSUMpasV+usFD1Wyh5r1TrDMGQcC84cazL7A+ff'
    b'DcDjRz+NIag5onnMkomipzgSLpz4fFOuT74dgKdPfhGlJo85/TBgEIeM45hgNQAi72/1sgWf'
    b'dfYmU9OdzHWzNluzGeazLrPZNFvSDh8/9eXr5fX+J+/DcGAJZm7y3ZvDieKdXicN8PDZe8hj'
    b'yUY9YqPKGdYlg1GhVy8Ni96lUeEQG6rGIoaoGhU1JVig0JJxLMhDzgOnfxaA3z73VsZxRK0F'
    b'EPAu4iQC9QQRED5w4V1NFM7fS6SR6mCKooQYqaqoZlaCGzgzuWbK0EozIjgEGgkhWqC2Ruff'
    b'd/ot1Frx9JeeJ1pjTFCeOPEZRBSZaMaZL3yeYJFHL7ydSQEB4MXh8ViEUKvFoEMRXXaIXLFI'
    b'z0oiteDweOdJxOPF48XhBATBMN53z5uJzWbMmeNNqJ880eyuhvLwvT9HEXOCBcCROE/Lp7R9'
    b'RttlSO2I4xgtWM/gokPtO1bLVS1QKiExb5lLyFxK5lMyl+LFIwhiAngw4cKJvwTg2BP3XSeh'
    b'1mR7s00HohlePJlLabmMRBPT0qjyqKHUa8C/OVRetEK/HwYohZBoQksypnzGlG/R8i0S2exb'
    b'HI4MIeXhs78AwPmJ979z7pdQAo6mRCuNlLEGhMynzRpBqEaRvF9rldcvm7NvOPlY/axVfC+W'
    b'thpyLWNhRuVISclcRuoSvDhMGkXDHJigZjx05l4AHjzzi0RtOiSZnGaGmTaE1FMXkTyvbTys'
    b'yzKPq6HSS/Jk/EzTDpn9p0Z7qRiH5fXVPI43KlztyMThRdhsG42IUqLUjRYgPHD6HtQqFCOq'
    b'J2iTId45Wj4lkxSrjfW1nKVra3EwLJdDrS+hfLdJTnHIP9mLdrc7ZFiXyHzLpVm3NSWtJJHE'
    b'CSLNVsIkq0UcjhTDYVKDGEKG4BGJOIHMJXj1xMrY2BjbpeWV+P1rvcFgWHy7rvVr8lQ4f50A'
    b'gHxdn9e75FZVdgIzGixzJjLlUtIkIfGeJEnxtPHSxkuGiMMMnKQkkpH5jE6a0PYpSUgo88DS'
    b'6gaXrq5wZaU3Wu+PLhZF9Xf2R/Xvb5bnDV2x1fZCqfXenoxQ1T1Em0k1SebVXGs6wScZopue'
    b'CgY4TRsHcIgTvCUQA+NRxer6SK8s98KVtdVhrz+6NCrqb1htL/yQPNz4XyAv2LftJ0XMyEOw'
    b'pIqxnRdVd1SUUpeRUEa0NKgUqSPUEakUqxQrA9W4YjgYca23wcWrK1y8es2WNtaX1obFS3lV'
    b'Pa+qX5Wn4ud+2Gl51Z/TR7LHvOOuVprctnW6M7e9O5vMdTp+JptyU0nikrSRKWh6Ho1m4xA0'
    b'r8a6NhrGl/v90BsO1qo6vhSMF/hY9aEfZebVCQD2kHuvpO7QdNbat7XT2T2VZNvSxM+luGm8'
    b'azvEC4KiEbMiqo5qDWujul7ZGI1+0C/Gl4l8R57RT76ajR9L4PpDR9NfEZE3CnJYkJvMbJuY'
    b'bcFJBoBahUgfkRXDLgry79HiN+1C/anXWvu/AQ/cnyW5eDxxAAAAAElFTkSuQmCC')

#----------------------------------------------------------------------
BtnGn06 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAClZJ'
    b'REFUWIVtl2mMntV1x3/n3ud53m0Wz4zHHm+D8UqApCRpIJRSkhKg0Er90CaoUvuplJBQymbi'
    b'8KVVPrRKsE2DmsYN3aSKROoipaVNaAHFiao2EhRlQdCACWCbmLFnPO/MuzzbXU4/vK+NE3ql'
    b'v67ueZb/2Y+uiLFoDPzU+iMyVmk2TGNW2um2hrb2ZWlyhVWzRyUuRjVzSpxUJQMQoRZMXySe'
    b'EzUno8TXnKteLKM7rlV9uorVKrOUfI76YhoxluRd5ACrTOPYXaVxdzsmuzdtmFvcObdj23Rr'
    b'YrMxzArS8TFmoMn4VyTGdpSoLij9ctB4c+XU9Om1M4u5jz/G8WNWeR1YvphGYyD5KeKPY1mg'
    b'A83L03b6y+2s+aGp9uTlO+a2zbx/53uTxZnNdrLVNKlNjYKoRhl5wKQCzTq4qbVhvnCyu7Q/'
    b'EH3lXTeV9KWhK57zwR/jnrJiiSH/yAWrL1ZA2Ni4BOPfN9Oeunrb7MKH5yfn9m6ant16yex2'
    b's3NuG7MTU6SpYAxEIoqigIAYhCykNrENrLFYgU2TMxNne6vmbG+1cbq7lHX7boaNyYtQvQEo'
    b'gL1Afg+TeK5Nstav79i47fr3bNu9/72L+2c+uHiF2TW/KFOtDmIieSgYhgEDPyQfo/AFZagI'
    b'MZLalMlmhy3T82ydntdmo9lGZK6oy/n1fDgdfb3OtXqa50b5YLmTlKs6G2nYKzdOTd+wfX77'
    b'L+1fuHTX5Vv2TG+b3Zx0Ok2RRKm0pIg5eRxSxIJaK6pYUavDxRqnDqeOgCeIBxsQizSSpm2a'
    b'VjMQ2oo2wQ+LoAM+kFU874aWX2ACr/vSduOmnfM7rtu3dde+y7bsnti7eYdpNlNZ9126bpW+'
    b'7zEIA8pQUIVqRBgdD9/9GNfdchW11pSxZBhy+r5Pz69ThZqpxjTTjWlEJFGrTRe87eZ9E6tq'
    b'jV+LS5brmwsG/blOa+LWPQs7L7ti2/65hdmNadY0UlLQ8z2KUFDHmjrWOPW46PHq+dwffAWA'
    b'bz/1PNfcciV1dFShoozVWEmPiCAiYq01iaRprxhkq/3V1Gm9pEX7lGlKujVrN3Z1mq3LZ9sz'
    b'm3bMbLGtZsaZ+ixL1RnykFPHkbUuOOo4wh/f+1cAPHDktwH4wn1/S+krylBThooiVPRcn1P5'
    b'Kd4qT2AbwpaZeTPT3rC502hd2Wg096aJLpg0SffNTW7cuX1+y9yGqYmGpl4qGcW6DDlOa4L6'
    b'C3jkqa/i1XPfkd8C4NEHnwDg7kOfwKvnz575J7x6nHqqWDH0fXphnaH28aY2kxPt5ra5LXNz'
    b'kxsXJZX9tn3D1O9cOr+4e9+WS3fObOikMakpdCBB63GRRQ498ATX3nIlSuSavZej4xK8+uYr'
    b'eO7pl7j70G+OZZGf37Uf1dHzxw9+nffftJ8oShUrCp9jjJVONulDiGvLayvBiLK3kTU2T09M'
    b'GJsJA+1JHgYE9SCRQ/d/FYAjD3wNiKBhBCIQ+f3DvwFjch3LIPL4wa8D8NeffZKojiIOyXUo'
    b'WdMwMzlpOs3mvKruNz767ZUWs95U1klNFQtcrIkEDt33NQAOPHr72N1/P+4feoHonfM78q8c'
    b'/BcA7vj8bQD8zWe/AQQUDyaAdbbWalbRS6R9cMPJXYuL7Sv37J5udZIEqWkklqbNSMRy+P5/'
    b'uNAqDzz68ZHzVVFhtI/P5+WM96Of+bcL393x+VuJKKiQ0KDMg3/p9Tf6P3jleM8EDRM912u+'
    b'XZ8151yXPJRU0VHHmqieg1/8BAAHH7sdY8Ceh4xgxrCio7MZ4dOHfxWAuw7dhjGQGFA8g7DO'
    b'WXfW9OteQyVMSvJQZzi1qW237JzNNky1ZTJpMpm2mEiadJIGraSBFXvBmgsWq7zbchRkFIbR'
    b'O6OJEWLAaaD0NX1XcK4/0BNvrNRvn1jzJmqkChVr9Ror5Sor1Srdeo2BH1CEkkPffJKo/kJm'
    b'j5QQohqCWlST8UxLMSQkYkiMIRlb/eWnnyXiyENOz/fphwFFKPDqGM2Ca+0BaSFMxgQbRUSx'
    b'IiRisEa4bu9euCjeI6sAzBijWQYyCoUBI4qME/IDu3ZQRUceCga+IPcVeV1pf71yxXpdGUQH'
    b'MYYy+BBjiESNePWUsaIIJbnPeeyBb1DEnCIOKcIQF0vAY03ASADcGAEQBIMRePT+pwiEceuO'
    b'RCI+BOo6RFWtwPSNqixrZKCVKgEMAiiRSFDP3z38XwAcPfDsaOrFmqAjMiGCBEQiIqM+ENTj'
    b'NfCFe/8VgL84cGzkajFYLBrAu6jBx4FIPGsQeUsDq1oRcILBYo0lEcuTf/gDAH73kesB+MuH'
    b'vjMiGSOOc+KdBI1UseTIfaM+8OBjtwLwxMPfpWkzmiZDnCEUIajXVYUThqjH1cmZWBKphUSt'
    b'ZiYhMym3/8k1o272mf8E4PceuQGwoELUSNBAVOV8DUQNeHXceegjABy59ykAPnX4RhomI4mJ'
    b'xkqp8xB9FZeBVwxRXtQy/sT3iZRCEhMaktGyGS3b4FOHbwLgzkc+AhgMGUJ6geyLD/wzPo7y'
    b'JuIx4xz45OGPAnDvn/4KmU1JJAEv1MNA3nOxzt3bavT7BuVVrXkzVHrO57EKpSq1ISUlMxmp'
    b'SbjnyM2oKKrw+LPHxh5QvvTgNwH40oEnCTEQNXL06e8gjHrEXYc/OlIoWlwZyHOnxcBVVR7O'
    b'+TqeJOorBsdpVF+PQV8uC3927VweivUa4wyZGKwIYs7HOHDHjb9IxHH0of8Ye+ZjoyR96N8J'
    b'0XLnx64nErDG0LApmaSoU9a6OUvL3dAfVGe9iy8TeQ3fWLJ82Cu+kWC1pegkgdmGSbPJRksa'
    b'SSKJEURGowQZV70Yrr75PfzPM8d54ZnXAfjkodsQLCIBI5CZBBstoVbW1ws9eXYl/GR5td8f'
    b'lP/rXPxvnLyAzV+3XEXENyoy14+RVowsABPRa2ZUpGVS0iQhsZYkSbE0sdLESsaHbrmM55/+'
    b'EXcdvo1EMjKb0U4TmjYl8QlV7lk6t87JMyu8tbI6XOsNT5RlfSzin8Elr3HUrVteIPI9l3N1'
    b'7BJsM8Q442JsuOBTCdhMUkmMEWMEQwqhgYkJRg2q8MEb9yLRYKLFqiHDIE4ph46V7iCeOnPO'
    b'nTq30ltdH7w5LN33o9Nj4L7LUbcK6DtT5jlqrurUpL6rSu69JnUIzbysJ4dlJa4K+CoQK4U6'
    b'Ii6AC0gd0Tqilacuagb9Icur65w4s8KJM8u6tL621B2UL+d1/e0Y47fwrR/y59UZxheTi29G'
    b'Srf3Jg2WQ2yeK6KraufK3jAP3WF7ZjCYTmbabTuRlaaVJCZJrYzuPxCJGoNq4X3M6yJ2h4Pw'
    b'dq/nVwf9bu3Cy155XoN+C+rvsVIPz5OfnyLvXp9uL0Dcg4S9kpq9nayxY0O7vbWVZBvTxM6k'
    b'mA7WNA1iBSESA6pliHHoou8OnVtZHw5P98riFIHjqD0O5jW+nC/9LFXy/17Pl/NlFuiSdV5V'
    b'X2/NXX1Z0XPvE2SfIJeo6kZRBSMZAFFrRHqIrCh6QpBXg4YfIvyIZnaaerjOEv5nycVY/g8+'
    b'Y1A7Vv5yiQAAAABJRU5ErkJggg==')

#----------------------------------------------------------------------
BtnGn07 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAACoxJ'
    b'REFUWIVtl1uMXdV5gL+11r6dc+bMeGY89vg2GF+JcVLSNBCaUpISoNBKVS8EVUqfSgkJpRgb'
    b'4uSlVR7aUnwJpDRWaNO8kEhJKrmgElNchUSVGgmKckHQgInBNjFjz8w5M+eyz957Xf4+nMPY'
    b'oV3Sr6X178v339Za+pXSBgmeXxp/RUKLLNXplKrHm1Kp7Uri6GojeoeoMBdETwuhKUICoBSV'
    b'QneVCktK9NmgwhvWli8XwZ6SsjpfhrLFFAVfpLoco7Qh+j9wgBYTWLaXcdheD9H2dWum57ZO'
    b'b9k0URtbrzVTCtVwISQg0ehXRNo0hCDWC92il761eG7i/PKFudyFn2P5OS1OAwuXYyR4ol8C'
    b'34FhlgZke+J6/Fv1JPvweL25Z8v0pskPbn1/NDe53jRrmY5NrAWUSFDDCOhYQVZ5O77cz2fP'
    b'tud3e4IrnW3HKn6lbwcvOO+e576iZJ4+32HV68sNUKxNr0C7D0zWx6/dNDX7kZnm9M51E1Mb'
    b'r5jarLdOb2JqbJw4VmgNgYAgCKBAaRSJj01kUow2GAXrmpNjFzstfbHTSs+355N2106yNnoZ'
    b'yjcBATCr8Pto4rg+Smq/t2Xtphvet2n77vfP7Z780NzVetvMnBqvNVA6kPsBfd+j5/rkIxm4'
    b'AYUv8SEQm5hm1mDDxAwbJ2YkS7M6Sk0PqmJmJe9PBFetcL2c54VhPRjuJuaaxlpSs3ft+MSN'
    b'm2c2/+bu2Su37dmwY2LT1Pqo0ciUioRSCgYhJw99BmFAJSVlKKnEYkOFFYsVi8fhlQPjUQaV'
    b'RpnJdC3z+LogGbj+wEuPX01KXrR9w68zhpNdcT29eevMlo/u2rht11Ubto/tXL9FZ1msVlyb'
    b'tm3RdR16vkfhB5S+HAKD5Qv3PsZHb72GSiqKUND3OV3XpeNWKH3FeDrBRDqBUioSI5n1zrTz'
    b'rg5luczvhnnDDdmsRn6lURu7bcfs1quu3rR7enZqbZxkWhUM6LgOAz+gChVVqLDisMHhxPHF'
    b'v/gqAN8/8SLX3bqXKlhKX1KEcmSkQymFUkoZY3Sk4rgz6CWtbiu2Us3LoH5OZyremNTTbY2s'
    b'tmeqPrluy+QGU8sSLlQXmS8vkPucKgy9td5ShaH89f3/BMD+I58C4O/2fZ3ClRS+ovAlA1/S'
    b'sV3O5ed4uziDSRUbJmf0ZH3N+kZa25um2c44klkdR/Gu6ebarZtnNkyvGR9LJXaqVMNcFz7H'
    b'SoUXtyqPnPgGThz7jvwxAEcPPAnAvYc+iRPH35/8F5w4rDjKUNJ3XTp+hb50cbrSzbF6tml6'
    b'w/R0c+2citVuU79x/E+unJnbvmvDlVsn1zTiEFUMpKe8VKNNFji0/0muv3UvQuC6nXuQ0Ra8'
    b'9pareeG5V7j30B+NdIFf27YbkeHzJw4e54M37yYooQwlA5ejtVGNpOm8D8sLy4teK2FnmqTr'
    b'J8bGtEkUPemo3Pfw4kAFDj3wDQCO7P8mEED8UAhA4M8P/yGM4DLSQeCJg8cB+NrnnyaIZRD6'
    b'5NJXSaaZbDZ1I8tmRGS3dsFtLmUw5XRprKoowwAbKgKeQ/u+CcCDR+8chftbo/NDVkGX1pf0'
    b'Xz34FAB3PXw7AP/8+WcAj+BAezDWVFJOCXKFqh9cc3bb3Fx9747tE7VGFKEq0siQmYRIGQ4/'
    b'8O3Vo/LBo3cMgy+CKIbzaP2untF87HP/tvrdXQ/fRkBAFBEpRe7dK6ff7P7ktVMd7cWPdWwn'
    b'e6e6qJdsm9wXlMFShYogjoOPfhKAg4/didZw9NmnMBqMGsqXDxxHKzBKMAq+cvJZtIbPHv4d'
    b'AO45dDtaQ6RBcPT8ChftRd2tOqko31TRQ43++Lq62bB1KlkzXlfNKKMZ1xiLMhpRSi1KMcqs'
    b'erPqsSgOP/CdVf2+I78/LFo1TMPwneGN4YPHiqdwFV07YKnbkzNvLlbvnFl2Okig9CXL1TKL'
    b'RYvFskW7Wqbnegx8gQ0VDz9zfLWyh0Zcgu87MqyPRw8cRxMRKU2kNZGGx587iSYQsOQ+p+O6'
    b'dH2PgR/gxA4vIXUgbSXTJqlvjmqNeqKbScaaZIyppMlE0mA8rpOaBINBKT0yQINEHN3/7csi'
    b'cCdaBYwOKOUR8XhxlN6S+5IV22elyunZkm6/CBfO9orW2X6hUdILwRfe+RB8IEjAiaMIJQNf'
    b'kLucx/Y/wyDkDEKfIyeewYYCcDz4pTtG8D8ALOA59N2nUWi0gqMPnMDjR0d3IBBw3lNVPohI'
    b'CbqrOJC+FE0wXZsxG5sTWTzRqDGWZIzFNZpRxtN/+ZNVL//s0I0gEOuETNcxKsKP8v3uUAqU'
    b'Eo7se2pV96m/vZ6+L+lWA1r9Pq3l3Lbn8/nufDGvUept8bSkxGMVGoPRhkiZVfifPnIDAP/4'
    b'0A8QAn4kgUvgYWoCZShW4Qceuw2AJ7/wQzKTkOkEZTV+4L04aQmc0QQ5JVZdCAWBShGJkURH'
    b'JDrmzr+5DoCvfe4/hxF45EbAgCiCBLx4gsjoCBKCeJxY7j70MQCO3H8CgM8cvolUJ0QhklAK'
    b'Ve6DK8MC8JomqJelCL9wXQKFIgoRqUqomYSaSfnM4ZsBuPuRjwEaTYIiXoU9uv9fcWFYNwGH'
    b'RqHQfPrwxwG4/0u/TWJiIhWBU1R9T96xocrtO6Llxxrhdal4y5ey5PJQ+kKEShMTk+iEWEfc'
    b'd+QWRAki8MR/PD+KgPD4ge8C8PiDT+ODJ0jg2HM/QKEQEe45/PGhQcFgC0+eWxn0bFnmfslV'
    b'4SxBXtNYziNyOnh5tRi4i8tLuR+sVGirSZTGKMVo9yF47rrpNwhYjj3076PIfAKAYw89iw+G'
    b'uz9xAwGP0ZrUxCQqRqyw3M6ZX2j7bq+86Gx4lcAbuHTe8BEnuDTCSE2QJp6pVMdJM62pNIpU'
    b'pBVKDa8S1LuVrrn2lvfx3ydP8dLJ0wB8+tDtKAxKebSCREeYYPCVsLIykLMXF/0vFlrdbq/4'
    b'H2vDf2HVS5j8tOEaAi4tSWw3BGohMAuMBSeJFqVqOiaOIiJjiKIYQ4ZRGUYlfPjWq3jxuZ9x'
    b'z+HbiVRCYhLqcURmYiIXUeaO+aUVzl5Y5O3FVn+50z9TFNXzAXcSG73BMbtieInAj2zOtaGN'
    b'N5kPYdKGkFrvYuUxiYpVpLXSWqGJwafoEKFFIwIfumknKmh0MBjRJGiUFYq+ZbHdC+cuLNlz'
    b'S4ud1krvrX5hfxysPA/2hxyzLUAu3TIvUHFNoyJ2bRFy5ySqvM/yomr2i1LZ0uNKTygFqoCy'
    b'HqxHVQGpAlI6qkFFr9tnobXCmQuLnLmwIPMry/PtXvFqXlXfDyF8D1f7Kf9QXmDUmFzeGQnt'
    b'zlukLPiQLQ2CLStri04/9+1+fbLXm4gm63UzlhS6FkU6io0a9j8QCBK8yMC5kFeD0O73/Dud'
    b'jmv1uu3K+led8KJ4+R5UP2Kx6r8Lh9Wyes/4bH0Wwg6U36livbORpFvW1Osba1GyNo7MZIxu'
    b'YHSmUUahCASPSOFD6Nvg2n1rF1f6/fOdYnAOzynEnAL9Bl/J59+Liv7f9nwhX2CWNknjdXHV'
    b'xtxWVw069gMKtUuhrhCRtUoEtEoACFKhVAelFgU5o1Cve/E/RfEzsuQ8VX+Fedx74Uob/he0'
    b'ijwtaAFPFgAAAABJRU5ErkJggg==')

#----------------------------------------------------------------------
BtnGn08 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAACmdJ'
    b'REFUWIV1l2uwXlV5x3/PWnvv93Iu4Zwk5OR2CAlJgCRIg4LRglXBWKbY1tr2Q6F2pgqdUhoI'
    b'BLx0rI5aKqFp6FiiaL18KWPr1NaK3AQi08GZ0CrCyBDut4aT5ORc3vNe9t5rr+fph/fNMdB2'
    b'7/nP3ut51qz/eq5rlojzmEbe9PwlGTPUa642Ls10dc0am7I02eLNnWWik2puqaEjZmQAIpSC'
    b'WxDRE2LuVRV9PoTiqVzDc1aURwotZhgn53OUp9KI8yT/ixxghiUENhSpbmhqsuH005ZOrlu6'
    b'dvWSxvAK5xgXZKhSzcCSwVIkzg8ZaiEaC3m79vL0a0uOzB2d7Fb6AoEXmOFF4PipNKaR5E3E'
    b'v4tngiGon5s20/c1s/o7Rpsj565dunrsV9ZtSybHVviRRt2lPnUGYqbS94BLBeplDKNzne7E'
    b'q7NTmyNaFVWYTSX9RSf0DlWxeoTr8oIpOvwzi1afugFhWe0MXHXeWHP0wtXjE+9cPrJ04+lL'
    b'xledMb7GrVu6mvHhUdJUcA4UxTAMEBCHkMXUJ76Gdx4vcPrI2PCx1ow71pqpHZmdymYXwhjL'
    b'kqegeAkwAL9Ifh0jVOxIssZvrl22+uJzVm/YvG1y89gFk1vc+uWTMtoYQpzSjT06sU276tAd'
    b'oFf1yGNBVCX1KSP1IVYuWc6qJcutXqs3EVnaK/Pl893OEq3KeXbYEQ7188FzNSnnDy2j5rcu'
    b'G13ynjXL11yyeeLM9eeuPGvJ6vEVydBQXSQxCsvpaZeuduhpj9IKCi0oLRC0JFggWCBSEaUC'
    b'HxGP1JK6r7tGPRKbhtWh6vSitdmeFTweOp53MUxlm9Jm7bJ1y9e+e9Oq9ZvOXrlheOOKta5e'
    b'T+WPrt7DRR/YwkLVoh3b5LFHEYs+oQY+ee0dvHvn+ZRWkmtOJ3ZZqBZoVfMUsWT3ri9y1e98'
    b'BBFJzFs9xMrPdhecFsUcv6FTnovrEw5721Bj+NfPmlh39pbVm5dOjC9Ls7qTP77mkwA8+MOf'
    b'sGPnNkotCVYRtKKyis/9+VcBOHjv41y0cyulBopYkGtBEQs+u+tOAH5w34NyxRWXukTStNVr'
    b'ZzMLM2mwcsp6zddcXdJVWbO2fqjeOHe8OXb62rGVvlHP+Pg1nwbg0/s/BsDnd91FiIEv3PMt'
    b'Sg18cdfXAdj9N1cC8KXrv0leFey97x/JY8He3d8GYNfevv5TN9/KyrHlbqx52oqhWmNrrVbf'
    b'mCY2ISOfGP/oaHP04lVLV/z+eWs2D2+d3GhklRwvj/FXAxKAPfuuwsxQATPDUPbfePei/tq9'
    b'vzeQs1gdX735u4v6z+y/jqSq2eHXX5LDr7/Qnpqb/t6x9vHv++Z7Rq86c/nkhk0rz1w3dtpQ'
    b'qklJz9oSrWTHzm08dv+T3LTvDzAUQ1Gxwb9x4Qe2cOiBX3Dt3o8s6g3DrP/dftlmfvqjw3zs'
    b'S79FoQW9qotzXoaykSpGnTs+Nx1l7FMr/m3rGees3bZu4zmNYVfXtMA5xYnAwFpOWmYDCjNs'
    b'0RP2Jjn8Uq4n9RiG4DShYcPErs8Pv/bi4cee+c/nXKXVmsJ645UrfJCSQnsELVEioNx+73cH'
    b'PeOt0AH+P7kCkX94+P7Ff6MCF8EHX1oxbtgZSbS4vBt7zZYuSNAErKQmHmcgeG6+/MNgJ5f/'
    b'ZYRNOHV0SuTtFBl8/P2XYgaKgURKeuQWpafd4ah2uosWh1uhVX+jPOZOhFm6MafQQKklahW3'
    b'Xf8dvAM3gD8J6cMN4MX647fM/dot9+IcJA6Minac51g45hbKVs0kjrhoWmuHTjKdT8uJ8gTz'
    b'oUU7dOhVOft2/wsAt+76DoLhRBYhuDfB4XHi8OJInJCIcGDPDwG46+Z7qSxQaN5vUmFeOrHr'
    b'Tak5NaWIBXPlHNP5DNPFDLPlHN/8xIMAXL/vCgD+etc/LbrVENQc0TxmyeBMS3EkJOJInOPv'
    b'bvwBAH92+04AvnHLQ7SqBRZim17sUVnoH0JyY20mW+qz5pqkMdTM3EhW57RsmPFshHs++8Ri'
    b'He/e9yFE3GADDizBzC1uCsCJ4p0iEjGL7L3+3xd1H/7CdubLLu1QsNDJ9eir7Xzm1U7uEGur'
    b'xjxWUTUqakplFbkW/PbnLwDg6tveR0+79LRDL3YImgMV3kWcRCAMEIF+eJzA7v1966+8dQeV'
    b'KYpSxUhZRjWzAtyCZ0dypauRJDUZqWWJb2QpmU9IfULqHNsvW4cT6TchFLWIiJBI0pdLvxRF'
    b'TlZAvyGJKCbK2y6dpNSKypQQI70i0OmWsdsqZ8pOOOoQed0iM1YQCYLD450nEY8Xz90Hf4qT'
    b'vl2D9kIcQE9xfz80SqE5eexSWQU4vvLAf1DzKXWfUXcZEhyxF6NVNmPwiued/u3ipOm9TNZr'
    b'WTrSrNtQrSZNX6eR1LhowzoS5xHkZKQHGe8BOWULhlokWEm0ChFAHBeddeZgnlCW0ebmuzI3'
    b'1y3zTnW4KvXnDpWnLNf/rhZQciHRhJpkNHxGw9f4xi2PkkhyCnmGkKIWqSywf/e/Umk/b5QK'
    b'N8iBUiNFDNxxw/1kPu2vUQllJ9JtBS274Q1z9oTDeNZKXo6Fnai6WsTcjNKRkvKtWx4F4M6b'
    b'foSJYQaYAxPUjC/f2K/zL9/0faJG1BQZvGbGgRsfAuCOG+4j5JFuN1ivHYqiG09Upb6K2mFH'
    b'4AhmL2q0p/NedWzuRDf25kvu/ovHALjhby8H4Gt7fowRueuhh1ACB/bcP6iQSwE4sOc+onru'
    b'fOAgSuSuPQcBuGX/hwD49md+zNTx2bjQLo5VQZ9GeZ6qNiVcxyihcS41/WBW95eMDNXPX71s'
    b'fHTDqhXue/sOnQw819z+XtQUM8FJgqfGgT33LGbANXsvR8yB5IgomUu4Y/cDi/p3fXRz9dLR'
    b'o635Vv7zXq961Ap7iDQ/5DkfpaoVZGFBlYYqE8CwVpa9/b3r5fChN7j+tg+SeE+SpHjqeKnj'
    b'JeMdO8/m8Qee4U9uv5xEMjKf0UwT6j4lqRK2/+o6Dh18gUv+8Bx7fXqmM9fqvJLn5SNK9SAh'
    b'eZ4DYd7zXyg/C10u1Fmir0fVsaBaC7FKJeJ3/NomSZwT5wRHCrGG0wRnDjO44P0bEXU49Xhz'
    b'ZDgkGHknMD3b1tH1jfDaienWzHz75U4entBgj0D4CQfCDGB+0UeHKDl/qCStZs3oVpUlZYz1'
    b'bl6OdPJCQhGpiogWBqUiIUKISKlYqVhRUfZK2gsdjs/M88rRaV45etym5uemZtv5092yPKiq'
    b'D1M1nuTvi6MMLian3oyM2dbL1DgetX6ip6EoQ8hbnW6c7TTH2u0lyViz6Yez3DWSxCWpl/79'
    b'BxQ1jWa9qtJu2dPZTju+0WpVM+2F2TLEpyvjcYv2MJQ/Y7rsnCQHFrvLm58/bU6AnoXEjZK6'
    b'jUNZbe1pzeaqRpItSxM/luKG8K7uEC8IikbM8qjaCVrNdkKYnu90jrTy3mtEnsP8c+Ce587u'
    b'1Fupkv/zen68e5wJZsmGnrWqXNUN5dm9VjhPkE2CnGFmy8QMnGQAqJWItBCZNuwVQZ6NFp9E'
    b'eIZ6doSyM88U1VvJxXn+B+y6CX5pzfcHAAAAAElFTkSuQmCC')

#----------------------------------------------------------------------
BtnGn09 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAACpFJ'
    b'REFUWIWNl2mQHdV1x3/33u5+/d6bRTOjQaNtJLSCFqKADcgOOHZsy6GCkzh2+BATpyoOpEKI'
    b'hISQl5Rjl+0QkJAlF0E2drx8CeWlAiGAhLBAplK4SsQ2S0EhxCaJiJFm9Gbmrd19l5MPbzQI'
    b'7A+5Xf/qW/d/6/77nHvO6TpKaYMEzzvGP5FQIy3p0qCqxAtLUl6VxNFaI3qFqDAaRA8JoVeE'
    b'BEApCoVuKBXOKtEnggqvWJs/nwV7TPLiVB7yGoNkfIXifBmlDdFviAPU6MeyPI/D8kqIll8w'
    b'Z2h06dDihf3lnnlaM6hQVRdCAhLNHEWkTVUIYr3QyJqlNyZO9p+aOj3aduFVLK9S4zVg/HwZ'
    b'CZ7oHcKfwjBCFdI1cSX+UCVJ39tX6V2zeGjhwO8uXR+NDswzveVUxybWAkokqK4HdKwgLbzt'
    b'm2q1R05Mjq32BJc7Oxmr+IWW7Rxx3j3BzVnOGC1+wqzV53+AYm5pCdpdMlDpu3zh4MiVw71D'
    b'Ky/oH1ywZHCRXjq0kMGePuJYoTUEAoIggAKlUSQ+NpEpYbTBKLigd6DnTL2mz9RrpVOTY8lk'
    b'ww4wN3oe8tcBATCz4jfTi2NjlJT/ePHchVddvHD56vWjqwcuG12rlw2Pqr5yFaUDbd+h5Zs0'
    b'XYv2DDquQ+ZzfAjEJqY3rTK/f5gF/cOSltIKSg11imx4ut3qD66YZqOc4kg3Hgw3ELOhOpeS'
    b'WTe3r/8Di4YXXb165MJla+av6F84OC+qVlOlIiGXjE5o0w4tOqFDITl5yCnEYkOBFYsVi8fh'
    b'lQPjUQZVilKT6nLq8RVBUnCtjpcmlyY5T9uW4X304GRVXCl9ZOnw4vevWrBs1UXzl/esnLdY'
    b'p2ms/uqG7Vzx0bU0XJ2mb5L5DrnPu4LB8vmb9vL+TRsopCALGS3fpuEa1N00uS/YuvnrXP9n'
    b'n0QpFYmR1HpnJtsNHfJ8ij8KY4ar0hGN/E613POHK0aWXrR24eqhkcG5cZJq9dc3fh6Axx75'
    b'BRs3racIBVYcNjicOL7yD98G4PD+p7li0zqKYMl9ThZycp/z5c33APDQgcfUtdd+WEcqjuud'
    b'ZlJr1GIrxZh0Kid1quIFSaW0rJqW1wxWBi5YPDDflNOEv7nxiwB8cc9nAfjq5nux3vK1h39A'
    b'ESxf3/xdALbe9WkA7tjyfTKXs/PAv5P5nJ1bfwjA5p1d/gu33c78gWE9UJkzr1oqryuV0pVx'
    b'JCOq93ODn+mr9F21YGjedZcsWt2zbnSlkDg1Xpzhn2dEALbvvh4RISgQEYTAnm33zfI37fzz'
    b'mXVms+Pbt/10lv/SnpuJXEmOvvm6Ovrmq82xqYn7zzTHHzSVD/Rdf+Hw6PJV8y9cOjCnGoeo'
    b'oCNN5aVg46b1PPXoc9y6+y8QAkIgKJmZC5d/dC1HDr7ATTs/OcsLgkj3felHVvOrnx3ls3f8'
    b'CXnI6bg2WhtVTXqd92FqfGrCq4EvzPvPdUsuXrx+6cqLyz06DXGO1gGtFMxYyznLZEZCBJn1'
    b'hLxjHd5eD+d4BEGhQ0RZevBtkx09+drRp176n2PaBbcol86g07mxqiAPHWwoCHggsGv/T2dq'
    b'xrsRgMDdBx/8retdeP7t8Udn54ID7cFYU0g+KMgSVdkx58Sy0dHKuhXL+8vVKEIVlCJDahIi'
    b'ZbqekJnjJfw/PCC/6QGBgIAoIkpkbe9eeO31xrNHj9W1F99Tt/X0reKMPmsnafuMPFiKUBDE'
    b'ceeWH2E06BmYc1BdfHPb/WgFRglGvb3v3N7v7NiP1hBpEBxNP80Ze0Y3inpJlO/VXkKpaVvR'
    b'RDahzhZnmbZ1mrZFx2Xs3vofANy++UcoBK3ULBR6lt+77QE0Bq00RmkirYiUYt/2RwC497b9'
    b'OLHkIesWKTutWr5tJFDSQQK5z5kqppjIakzkNSaLKb7/uccA2LL7WgD+ZfOPEYQ7Hn4AQbHr'
    b'lp90+buuA2DPtvvRROw98AiR1nxz20MA/P2uTQB8b8ch6q5Bwzfp+A5ObPcnpLaVasmQSSqL'
    b'onK1kujeJGVO0sNg0svDX35mNo+37v44SululKNBInZv/fEsv+Wu69AqYHRAKY+IZ+eW/5rl'
    b'P/G1S5ku2jRtTqOVhdMnmlntRCvTKGmG4DPvfAg+ECTgxJGFnD/96mUA3HDnh+iENp3QouNb'
    b'2JABjlu/8akZ8U8AFvBA93q0gq17utZ/+vaNOAkEAs57isIHEclBNxTbSr+M+hkqD5sFvf1p'
    b'3F8t05Ok9MRleqOUapSSmgSjFGomI2KdkOoKRkV4wmz+d10KSglGeTyWli1o2oyWz2kUHWqt'
    b'FrWptp0ca481xrIxjVJviqcmOR6r0BiMNkTKYJThvsO/QquuXTPJhZ9BQNi9/6FZcSGQh4zM'
    b't3HiAM23Dv43JROTmoRUJyir8R3vxUlN4LjhSvMepVXFGDWalpK4t5JKtVRSFZNSjkpcsXwp'
    b'kTYo1IyMnol4AyiuXLHqbXnxWCnw4lAKUJorVlwIKARFUXiZmm6rqal2kbXcUVeEZzVBPS9Z'
    b'+F/XIJApohBRUgllk1A2Jb6340kiFZ0nnqCICeJxYtmz9QFc6MZNwKFnYqAIntxb9t7yKImJ'
    b'u2c4RdHytOs2FG37lmh5RiO8LAVv+FzOunbIfSZCoYmJ+cGOJwG459afIapb0RANoggi3L2t'
    b'm+d33/ogPniCBNTMIyLs23aoWyduOYDNPO22lU7T5nnbn3VFOEGQoxrLKUReC15ezDruzNTZ'
    b'tu9MF9z3j08BcMs3rgHgO9t/juC599AhApZ92x+dyZAPA7Bv+wF8MNxz8DABz73bDwOwY8/H'
    b'Afjhl37O2PikbzTzM86GFwm8giuNKW6mD1teQyl8LEnN1b3VdMPCuYN9yxfM0/fvPnLu4rlx'
    b'1wcJEhBRaBVhKLFv+8OzAXjjzmtQokFlKBVIdMTerQdn+fd9ZrV7/fTp+nQ9e7bTcU9KLoeI'
    b'syOGDQRcKSexjRAoh8AI0BOcJO/54DJ19MhbbLnzY0TGEEUxhhSjUoxKeO+mi3j64Ev87a5r'
    b'iFRCYhIqcURqYiIXcenvLeXI4Ve5+i8vljcnaq2peut4lhVPBNxj2OgV9tlpwy8J/Nq2uTxM'
    b'4k3qQxiwIZSsd7HymI2/v0pFWiutFZoYfAkdIrRoROCyP1iJChodDEY0CRplhaxlmZhshr5l'
    b'ZXvy7ES9Nt18o5XZZ4KVJ8D+gn22BoiZ9dERCjZUC2I3KULbOYkK79N2VvS2slzZ3ONyT8gF'
    b'ioCyHqxHFQEpApI7ik5Bs9FivDbN8dMTHD89LmPTU2OTzezFdlEcDiE8jis/x7/mp5lpTM7v'
    b'jITJ+huUGPchPdsJNi+szeqttp9sVQaazf5ooFIxPUmmy1Gko9iobv8DgSDBi3ScC+2iEyZb'
    b'Tf9Wve5qzcZkYf2LTnhavDwOxa+ZKFrnxIHZ6vLO8XeVEQgrUH6livXKalJaPKdSWVCOkrlx'
    b'ZAZidBWjU40yCkUgeEQyH0LLBjfZsnZiutU6Vc86J/EcQ8wx0K9wT3vs3VLRb23Px9vjjDBJ'
    b'Un1ZXLGgbYuLOnV7iUKtUqglIjJXiYBWCQBBCpSqo9SEIMcV6mUv/jkUL5Empyha04zh3i2u'
    b'tOH/AGr3DaAZSlvDAAAAAElFTkSuQmCC')

#----------------------------------------------------------------------
Gn00 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAG1J'
    b'REFUWIVjYGRiZhgoMJB2j4JRMAoGD2CkSLcd6384+9Bvyswi2WJky3GJ0cxySuRpajlNHUGq'
    b'oUSqZyLLMXQH5AYpEfoGPAQG3AHEg5GdCGFgQMsBYg2nW3FMpbpgiNaGo2AUjAJqgoHungMA'
    b'QTQhz9/ISS0AAAAASUVORK5CYII=')

#----------------------------------------------------------------------
Gn01 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAExJ'
    b'REFUWIVjYGRiZhgoMJB2j4JRMApGwSgYTsCO9T8l2hmpZvmh32SZxUSp5X0z6jEdQwIY8BCg'
    b'HFCYBkbBKBgFo2AUjIKBBwPdPQcAK7QMyttwF8cAAAAASUVORK5CYII=')

#----------------------------------------------------------------------
Gn02 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAJNJ'
    b'REFUWIXtlz0OgDAIRvnRxUN5Ok/mtYzWpRgXYmiJGANTt/dKvpYWkRgia5BFOfZXwdfGIzuA'
    b'xEBh9FopkAIp8DOBeSxxAgI3SvgICHTd0CqBSOwziO5QEXmCEzsPI2P7fQSWyRy8foGGtGsC'
    b'9hA2pl0rm0BH2rWyn4KGtKvwL2Qg34QpkAIpQAAxd4EwMfp7fgIGzyPAIN9DjwAAAABJRU5E'
    b'rkJggg==')

#----------------------------------------------------------------------
Gn03 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAJ5J'
    b'REFUWIXtlzEOgDAIRQvo4qE8nSfzWkbrIsaYaIOl4ABTt/8ofGgBkJJndHzI22oqfCbueQOA'
    b'lNBN/YgACIAA0AcY++wHwOICCD0AFp0XkEAAIOntgasog7yJIzXYBYLr1wOYBlHj6QLcxQUw'
    b'9QAfM68DKNVY2AMyG5Z83nQOPPmcy2AyB0o+N5kDyj0Qj9IACIB/AHhYkTXB+3u+A8+1NlI3'
    b'S3tqAAAAAElFTkSuQmCC')

#----------------------------------------------------------------------
Gn04 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAJ9J'
    b'REFUWIXtl8ENgDAIRQX04lBO52SuZbRexHiwEUojNYFT05D8V/ILLQBS5xk9L9K+fSp8Hdyz'
    b'AoDUoZv6GQEQAHaAaUh+ACxugCgHYNFlBQsEAFJ5F7yLMohGHKlCJzSUvxxgHp9Fc/tVALQn'
    b'FeTLZ4HW7Yr8dwCt25X5slugdbswvwkP/OgW5MLYB2IWxCyIZ3kAtAHgYUTWBO/v+QELhUQe'
    b'dbYyAwAAAABJRU5ErkJggg==')

#----------------------------------------------------------------------
Gn05 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAM5J'
    b'REFUWIXtV0sOhCAMFcxs5lCezpN5rckMs2pEhLaPj7DgJS5M29eX2hZZjF2XXuiZ+xQBByRU'
    b'u983S4DNiqqIKWBsRBtuezk2KGLnxg37BESeEiHZiwQQ6fExl/f97Vi7AHYPGLte59snpUQx'
    b'kYH9xqPFEz2gB5W6lf/4ADob8dcdRlLzFfjLY4iOF+jfvQJ6NOoBHOF4hYnA8SsrT4VSs03I'
    b'brDM3X/LIQlgd7iyAnXPAk5ECU8qkB6EyPf342No9k84xKVjYkKF3tfzP9W7VjZydEdrAAAA'
    b'AElFTkSuQmCC')

#----------------------------------------------------------------------
Gn06 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAANhJ'
    b'REFUWIXtV0sSwyAI9TPZ9FA5XU/Wa3VauwnWGIiIUbLwzWSD8ngC8WOs80YLmrEnIixq7Fib'
    b'8P2UBXCAiczJx2BdQou7OAOH4K+3iMvVTN6lHYJD4ERMcw9hBNH2fPxXvS4hfoBtvEmEdR5f'
    b'LQbm2IET7JQAY7aultY589txJjjvgZM6X+WnngFcVU0PMEVQPUAK6AGMt7wPpL+dBBL/W2Sg'
    b'Rw9gKJcASGpFMP3mPoCrGngWkAJI24jTkCUsDZyJqAmufiNqh9ad8Kpbsfq7YEL1iWydNz8+'
    b'YXYi5nEtFAAAAABJRU5ErkJggg==')

#----------------------------------------------------------------------
Gn07 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAOFJ'
    b'REFUWIXtV0sWgyAMDPDceChP58l6rb6WboRGCOETa7pg3nNDJDMkIwIY60ALmtwTEYYc/GFv'
    b'/PtVF9ACSmSa/B5si5dMH65ARv54DuWyPS+fyh7IAzESI/YQlSCO7et31dvi4xNwxEUijHX0'
    b'aik0xrKcYbwkAOBw9Wifk3mnnAi8B5g+XzVPvQK0Ks4D2IRpLI1LPNCktLM6VN7qPmCsy1eN'
    b'ybk+76uvfY7qFSi+qO4BgLkP/Os+wBExsZIHigKKY3f8DZuEYeJERA+5+olIDq0z4VWnYvV7'
    b'wYTqFdlYBx9QSpwTrNAehwAAAABJRU5ErkJggg==')

#----------------------------------------------------------------------
Gn08 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAHhJ'
    b'REFUWIVjYGRiZhgoMJB2j4JRQAKwY/1PS3lGojUf+o2pllJ5BgYGJoKWwzTC+C1c/ymSRwMD'
    b'HgKEAY3TwBAAsDgdKP0DDyiNQ5qWA6RYTrVygFTLaVoOEOsIcvVjGDIQ+gcejJYDo+2B0fbA'
    b'aHtgFNAaDHT3HACuDnK9CZf8ngAAAABJRU5ErkJggg==')

#----------------------------------------------------------------------
Gn09 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAGNJ'
    b'REFUWIVjYGRiZhgoMJB2j4JRQAKwY/1PS3lGojUf+o2pllJ5BgYGJoKWwzTC+C1c/ymSRwMD'
    b'HgKEAY3TwBAAsDillfzgB6PlwGg5MFoOjJYDo+XAaDkwWg6MAlqDge6eAwCo7YW3FzFSnQAA'
    b'AABJRU5ErkJggg==')

#----------------------------------------------------------------------
BtnSmlGn00 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAwRJ'
    b'REFUOI1lk19olXUYxz/P733fc45zy7OGr7E2BRloaaUjCxNzqBloRK0Y3khIyQR3IV6aB3cm'
    b'FATBSiNN+nsRFC2CZmIbBnkhlH+qaQ6CGq6teY5n7pztvHvPeX/v79eFKzZ8Lr98n8/N83xE'
    b'lMP8sV1qLZF6FWQH0DwXj4L9Hteelvfi3+f35T+AzcQJcqnexnq/88C2varFb1wAHp4Y5dQP'
    b'n5nxO7n38cNDcsyp/g+YWz67+6nnt764bhuCS0HfIjSzGGtIqRT1ro8j0Hd1gC8v9g/ih7vk'
    b'mFN1RBQ8lDzesfG5jvb12xmeucFEdZxSVCSIA8o6oKhLTFTGyVfzbG5+Gjyz8sbwSFoum7NC'
    b'V2K1X7v0+lsdh9VQ+QrGGqy1WCzvZD4HoDP7MmYuw8L6uifo7nvb5Mu31zi0ekf2tL20cdIZ'
    b'wxBh0Rg072a+YH9PO61tq/jg6Nes29JCbDUazT+VMR7218qVP4YihfCMSWnuRJNYIoSY45mv'
    b'ONDzAoJGJOa17C4+yn4LohE02s6SWmxA5FmFZfnV6V+ZikqU44DeI30ceqMdz4GEEjyxJAT2'
    b'9+zkk+w5XAccFXOtPASW5S7AnzN/Edj7aKlrAsBYA4A2HuAhQMoN756bkL+DPJPVEgAK4WY0'
    b'GxFbQzEqsjvzJL2vf0NRF/AcjUiISEjv4X4OvrmDQFeIMcwEVRBuKiwD8SQkHZeUkyDpuOzN'
    b'bubjoxfQRgNwItPPK92bsFao9RZRn6gjLERg7TmhK7Fa4VzfsGmFWrl0Gfd7S5iJS7gs4cPu'
    b'7wDY17MVgKqpUJ9MM5LPceb8LyYyeo0jl7htW9UDlaC6YZXfyOIalzCuYqjweNsjPNrmI7aW'
    b'yJZJJ2ohVAz+9BtTpfCknNSf3v3EndFAkDNbCqXpFQ/WNJBO1+DaBlzxMNYhpWpYlqpjOlfh'
    b'zM+XGb01dR4/3CM/qvgemRYlvM7HmptUU7qB2mQSEMIoYmyqwKWRETMb6VP44cEFMt2rs7MP'
    b'2L5QZwbx4tNywlyb3/8X+nxf2LqaCTUAAAAASUVORK5CYII=')

#----------------------------------------------------------------------
BtnSmlGn01 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAs1J'
    b'REFUOI1lk01oXHUUxX//j5l5TSfphOgTalJBurC1oHUhVKiKrQpaBBWCmy6KSBdmIS5FWyU7'
    b'QRC0tWlduRQqXViKpii4cVHbKqkmKNWQNDGZcSaZycybj/f+97pIDIk9m3s5nHM29x5jrGMr'
    b'dMweILWvg3kOGNmg50G/xesFcyb8tlVv/gvQ90KecvTx7sH45JtHTti98e5twTNL80x8/4Us'
    b'rpQ/I+68bcZdbzNgw3zltSdeeublR49g8FSzZTrSRlSIbMSgj3EGLt6c5Msfv75K3HnRjLue'
    b'M8bCvsIno4eOjb5y8CgzzWmWeos00jpJSGhlCfWswVJ3kUqvwuGRJyEnD07PzJbMdbliGMs/'
    b'FBfv/fXD0XfsVOsGooKqoihBA4ISVJANDoWD/Y/z/sWPpNL652HHY7l3jz/96qGaW0BIUTKE'
    b'jEwzAoGgGaIZout7Rsbf3QX2xwfMjT+mUovhWYkyVtIaSoohYBAMgXOnvuL86UtgAsYEMBmG'
    b'jEzbRDsFjHneouy5ufYLq2mDVkjwFryDM6cubV7g89OXyVnIO4N34GzgVmsKlD0e4M/mXyQ6'
    b'wN7+YQr2HnK2wP8ReYuI0Awd7iQVar0GABbDXNpOCSrU0zrVXo16VuXEB4c3zWPjx0A91glJ'
    b'1iUgNJMeGOY8ymSosb8QeyKXp+A8AKKybtzASlqhlC9SzO1gUAK/V5dB9RuLl3PtJZEojRgs'
    b'DFB0A4gKnl10NaEdhK4m5G2B1V6TYm4n2jZU5lqC1/PWnA0zEnTi9nQZ33Z4JwBk1BGJNmdP'
    b'upTyRbQN136+TZrKhDkbZtY/8YV0MinLU9XG2gP39w1RKvXhdQhvcog6ItvHfVE/a+Uul69d'
    b'Z3559TviznHzgw13lWlHPnfykZFhO1waolgoAIZOmrKwWuWn2Vlpp9kEceetbWW6u87uDeDo'
    b'9jpzlVy4YD6VW1v1/wJGAnJ2EvXjogAAAABJRU5ErkJggg==')

#----------------------------------------------------------------------
BtnSmlGn02 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAtRJ'
    b'REFUOI1lk09oHHUUxz/vNzO702RTNkTHEpOIUrBqwLagUKG2tFWrFsFagpceRGsPyUE8ig0l'
    b'uQmCoLGpPemxtDclaIKKl0L/pGiqCRQ0JCam2SbZ3ezOzu7M/J4H0yUx38uDx/t+4T3eR8Q4'
    b'bJYOmF5i8y7Iy0D3Rnse9AdcvSQj6R+b5+VBgJ5LMyz7n3W2B2f7j75jdgedW4Jnlua5+NM3'
    b'dnFt+QJB9KEMO41mwIZ57O0X3jjy5t6jCC4ryT0iW8OqxTc+7W6AI3D19jiXr307QRC9LsNO'
    b'wxEx8FT2874DJ/pO7jvGTGWapcYi5bhEmIZUk5BSUmapvkihUeBg94vg2SemZ2bzcsuOCQOZ'
    b'PUHu4d8/6fvITFUnsWpRVRQl1RSL8uXgZQDeO38SFPa1Pc/5q5/aQvX+Mw77vY9PH37rwKqz'
    b'gCVGSbAkJJqQknJh8ErzDpM/T9N76HH+qS/wdNArk3enYoPwkvUT1uJVlBghRbAbNeH/EhIS'
    b'reG3WhB5xaD03F7/lWJcppqGuAZcBzwHMkYYGD7RNL8/dBzXAcek3KlOgdLjAvxZ+YtQd7K7'
    b'rYuseYiRc2MA9A+dAjz6h07huRHWJlTSiL/DAquNMgAGYS6uxaRqKcWlphlgZPAKIhEiEaiL'
    b'cSxhUifFUgkbIMwZlPF0FbKOi+9ktu38QGtxAVUh5+2gPdNGtBKD6vcG147Wlqz1Y5/27E76'
    b'h19tms4MHaGWWuoakjFZio0KOa8VrQmFuarF1a8cucl93W921cPGc08GnbS2uOw5uIu9h3sQ'
    b'zZFQQjRHrFXymRxEhonrv1EsR6Mymnz93ye+Fo+Hy/bQSnn9sUdbOsjnW3C1A1c8rDr4poVH'
    b'/DbWl+t8d+MW8/eKPxJEp+UXk26DaUfGO/tsd5fpyneQy2YBIYpjFoor3JydtbU4uUgQfbAF'
    b'pu04O2eAY1txZgIvvSRf2Dub5/8FS/tP3NiR9ksAAAAASUVORK5CYII=')

#----------------------------------------------------------------------
BtnSmlGn03 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAtVJ'
    b'REFUOI1lk09oXFUUxn/3vvdmXsaMnRj7CjVpIXRR26JWUKhiFVsrWBH/QHDThYgUNIviUiyK'
    b'QQRBEKyV2J0rEeqqpWhKFTcitWklrRmQamhMTGdM2plMZt68d+85LhJDQs/mcD7O+Q7n8H3G'
    b'2ID1oSN2D7l9HcwhYHAVngH9nlBPmc/97+v7zf8EetwXqMWfbu1Ljr514DW7I9m6gbg6P8PY'
    b'D1/J3K3aFyTp22Y0yNYIVofPvfrYC0+/9NABDCEL7iapdBAVYhvTFyYEBk5fHuebn8+cJ0kP'
    b'm9EgC4yxcH/xs+F9zw+/vPcg1dYU89kczbxB27dZdm0arsl8d456VueJwf0QydBUdbpiLsk5'
    b'w0hhZ9K7+drHw+/YyeUJRAVVRVG8egTFqyCrGAp7y4/y/ulPpL787+6Ah6N3jzz1yr7FYBYh'
    b'R3EIDqcOj8er48v3vmXixyke2D+Ew/FPd5ZdyR4z8cdkbjE8I7HjVr6IkmPwGGQ1O4zx617u'
    b'MDicdojvEjDm2RBl2+Wl3xgoVwisUolKCGAVVA1ehTc/OIygCIJXBfFcbU6Csi0E+LP1F229'
    b'mx3lAYr2XiJbBMBJBEQYIA5TRISWT/m7XWcxawIQYriRd/JdviQ08gY9meXr0V8AOPbhizhx'
    b'nDh+ZqX+6BDtbheP0GpnYLhhUcb9IhSDkDgoUAzCtZOduI0qVUNv1ENfoUy6kIPqd4aRwk5L'
    b'cO2Rx7fboc1buCfaRMs3CdmEtSkiMdamAGTSpa9YYbpe4+yFK5KL223NSV8Vr2PXp2qEnYAw'
    b'kJXtNBCJ13ImXSqFXrQDF69cJ89lzJz01RUlPpePt2vy5EJzaft9pX4qlRKh9hOaCNGA2JbY'
    b'EpdZqnU5e/ESMzdvXyBJj5ifrL/DTD2F6OiDgwN2oNJPb7EIGNI8Z/b2Ar9OT0snd2Mk6bEN'
    b'ZrrTzsEbwMGNduY8kT9lTsjV9f3/AbuqaXX7Ri4oAAAAAElFTkSuQmCC')

#----------------------------------------------------------------------
BtnSmlGn04 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAuRJ'
    b'REFUOI1lk01oXGUUhp/vu9+duZPMTGYYvA0xqSAF/1q1YqUtqKWt9ZeqRYIbF1LatNhFcamE'
    b'WosbQWhp1dS6sQsXQsFFNWiCgguFNrXY36xqaDRMM/mZTDI3d+7Pd1w0hoSe5cs5L+dw3kcp'
    b'7bCy5JBeT6z3gtoF9CzJ4yA/Y+SM+jy9sbJf/W8g/WmGSe94V9nve2/Hu3qd37XKeLQ6zulf'
    b'z9qJ2ckv8cP31TEnWjZYGh58e+vu7W8+uQOFYTq5Q2gXsWLxtEfZ+DgKzl0e4rs/zg/jh6+q'
    b'Y07kKKXhkezJ3i2v9e7ZuJPRhZtUowka8RxBGtBMAuaSBtXWBLWoxrM9z4FrH7w5OlZSl+yg'
    b'4lDmYT9/3/VPez/QV5t/YsUiIgjCif5vAeg7+hZ2SUNgY+EZPjr3ma01px7TJPrAns0v6ysL'
    b'I6QSYYlIaRFLa/n+VCJSiUhsi0hCLjZ+5/XNL2kStd+geMF6CbPxLEU3hwIUgsJy8OPdWIRU'
    b'UhQCpCgREonJtxdAqRcNwtrL83/RXSjhaOHrI4MAHP7kDUQUqVgc4IsjPwKw9+gusCnXGldB'
    b'WGsAbi38TSBF1hW6V70usS7golbmhJB/ghozUeNuDjjoXS9ucB7tqpTpzHXQmSuTMxkAOkyF'
    b'xCYAGG1AB1SDOaphndtTM9y6MHNDIwylM5B1DJ6TIesYAKxYjn/4Paf6zwMwG9cQUeTdHOVM'
    b'gXA6BpGfNMYOLFat9WKPcrZI3ilixWLoWF67JQEZnaUeLZB325FFRe1202LkK0eNMCVP6c5W'
    b'EG16yO+ivc0QphGWFk9v28Dj23yU5ImlSSmTh1AzfOEK9UY4oAaSb+4m8ZV4KJi0z0835h+4'
    b'v61CqdSGkQpGuVhx8HQba7wC85Mtfrh4ifE79V/ww3fUbzq9B6Zcxu17oqdbd5cq5LNZQBHG'
    b'Mf/WpxkZG7OLcXIaPzy8CqZ7cXb2ATtX48wwbnpGnbLXVvb/B0cZVfk5JJmOAAAAAElFTkSu'
    b'QmCC')

#----------------------------------------------------------------------
BtnSmlGn05 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAudJ'
    b'REFUOI1lk0toXGUUx3/fd787cyeZmcwweA0xqSAFn1UrKlVQi631UfGRRXTjQlqtYpDiUq1t'
    b'DW4EsWCtqXWjuCoUXFSDJih0odCmFvvMqoZGwzSTx2SSublzH99x0Rom9OzO4Zw/53D+P6W0'
    b'Q3vIoL6HWO8AtQ3ou16eAvkFI0fUl+nF9n71v4DsSTPMeAd6yv6ud7a8rtf7PWuEJ6pTHP7t'
    b'Ozu9MPMVfvieGnKiVYHrwyOvPvrCky/fvwWFYS65SmhXsGLxtEfZ+DgKjp0Z5egfx8fww+1q'
    b'yIkcpTTcmf1i4JHnB/o3bmVi+RLVaJpGvEiQBjSTgMWkQbU1TS2q8Vjf4+Da2y5NTJbUaTui'
    b'GMzc4edvuvDpwPv6XPNPrFg+//B7AAY/fgWLcOijowDs3NcPAhsLD7Pv2Ge21py9W5Pot/o3'
    b'PavPLo+TSoQlWr07ISaRtty2iCTkVON3Xtz0jCZRbxoUT1kvYSFeoOjmUMC7Q/2kYrEkKCXs'
    b'3L8dESGVBCVCIjH5zgIo9bRBWHdm6S96CyUcLXyzdwSA3Z+8hIgiFYsDHNr7EwA79m8Dm3K+'
    b'cQ6EdQbg8vLfBFJkfaF3zesS6wIuqt0nhPwT1JiPGtd8wNveheIG566eSpnuXBfduTI5kwGg'
    b'y1RIbAKA0QZ0QDVYpBrWuTI7z+WT8xc1wmg6D1nH4DkZso4BwIrlwAc/cHDPcQAW4hoiiryb'
    b'o5wpEM7FIPKzxtjhlaq1XuxRzhbJO0WsWAxdq2u3JCCjs9SjZfJuJ7KiqF1pWox87ahxZuUB'
    b'3d0Koodu93vo7DCEaYSlxYObN3DvZh8leWJpUsrkIdSMnTxLvREOq+Hk22tOfC4eDWbsE3ON'
    b'pVtv6ahQKnVgpIJRLlYcPN3BzV6BpZkWP546zdTV+q/44WvqhE5vgCmXcXfd19ere0sV8tks'
    b'oAjjmH/rc4xPTtqVODmMH+5eA9ONODtvAFvX4swYbnpEHbTn2/v/AwYYT0I+zzUhAAAAAElF'
    b'TkSuQmCC')

#----------------------------------------------------------------------
BtnSmlGn06 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAuJJ'
    b'REFUOI1lk1toXHUQxn//c9k9bjbpxoWjxARBCxqp9YJ90NKLpl6IRbRC8UEtViQhLVgEn6o1'
    b'Gnw2eE1tXhQEEQURpeSCFksppC2CaBt80JjUkGSzyWaz2T17LjM+NK4JnccfM983DPMZY9ls'
    b'LD1qbSOyXgbzGNCxjmdAR3H0lPkoubyx3/wnoG8mKRa8wbZWv+dI10vWVr9tk/Dk3Awnf/pc'
    b'ZpcXPsEPXjMDdtgQWB8+/dxDTz3yzL1dGByK8TyB1BAVPMuj1fGxDXzzyxhfnf9+HD940gzY'
    b'oW2MBZ3pDw4+uP/ggfv2MVm5wlw4Szla4fjr7zM6co7te25nrj5LISywq2M3uHLblcmpnLkk'
    b'px3ts+/0s/me7m0PM1GaQFRQVRRtrL8clpF1Nh+M0tW5i7OXJ44U+hY/NvR6g71PPP9q5sYE'
    b'IWbwjS8B6HvnWQRFVBAVhvu/A+DFE91YODirWxge+eI9C8Oj4sUsR0so0f/XJcEQY0wCJtnA'
    b'Y2Kt4TUJGPO4oddb3dHVmW1vzpFPN5NzMw1nVSXRBFG9xhASFWKJ+bu8yJmR3ysOwJ+Vv6hq'
    b'C1ub2xl+6wIAx959mlhcwMUAQye+BuDw27u5Wi2wFJYBsDBMR7WIRIWVaKWx6kpcxLVjjAkw'
    b'JmjwalwnQahUQzBMOyhjyRJ3pX0Hz05xqH8nlrEQFQaPfwvA0YH9HOrfSS6VZS2u0yoJfxTn'
    b'QXXEwpGh2pyIF3m0plvI2i2ICg5bGq51rZKy0pTCClm3Ca0ZCtNrgqOf2uYii3q/dXO9Gu64'
    b'w2+jKeMQJCFCnQf23s32vT5Gs0S6Ri6VhcBifOJXSuVgyAzFn137xO5orLoge4rl1VtvyeTJ'
    b'5TI4mscxLqI2npXhJq+Z1YU6P1y4xMx86Uf84AXzs5VcF6YbUm7PPR3tVnsuTzadBgxBFPFP'
    b'qcjFqSmpRfFJ/ODYpjBdH2f7FWDf5jgzjpucMh/Kbxv7/wWykVzjEPpvRgAAAABJRU5ErkJg'
    b'gg==')

#----------------------------------------------------------------------
BtnSmlGn07 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAtBJ'
    b'REFUOI1lk0toVHcUxn//e+/MvUlnzIypI9oEIbowmmq7kKISpcZ3RLQFcSGCiCREoSK4qU2x'
    b'BtcOtkaCdlMoFEFoi68kokIphahooZrZqOMrJJk8zDhkbu7j/Ltwmkzqt/w45zsf55xPKcOk'
    b'HPqI0YBvHAS1Gagt0S9B92DpC+pc+Li8Xv0noNvDKMNOemEy1XK46YCxJLVwlnBm8CVdt3+S'
    b'gfHh86TcY6rD9KYFSs3X967ZuWH3J00oLEaDIVwpIlpwDIeklcJUcPlBL5f+unKTlNusOkzP'
    b'VMqAevv7Pat37Pni041kCv0MegPk/QlOHD9LT/efrFi/mMGpAXJejsbadRCRuv5MNqHuy3VL'
    b't5lLU7Hqlu0Nn9P3pg/RgtYajZ62P+7lkRI35PbQVN/IH4/7DufaRjoVrU66deu+ryrnhggB'
    b'6W9+AaDt1JcIGtGCaOHiyd8B2P/tdgwsrLdVXOz++YyBYpM4AeP+GBp/ZruEKAKUCkGFZXxA'
    b'oIs4HwgotUXR6rxd1VQfq4knqLbjJCKV05PTJ34tuWl+xyGEWggk4Hl+hDvdjwoWwNPCMyb1'
    b'HJbEa7CND4kY9qwTKipwLBcRoRC6vJrMMeblAbBQvPCL/rKwUpjwJ/it/S4AB75r5OjpXQQS'
    b'AC7pr68AsLf9M0KEwqQHihcGmt5wDGzTwjGj01OlZPX/iEUqSEbjuKM+aN2tOBJdamA+WrV2'
    b'kVE3bz5zI1UUwjwWVfx48hoAh05tAMCTKZJ2gmxumKu3HoovwXJDdYYZCXXXk/5hrKKJZQoA'
    b'ARMzbsTBkykS0Ri6CHcfPsH3pUt1hpmZVx6yez+an1i3qeFjqhY4BEEcAFcmcYxKkjaMDOa5'
    b'8fcDskNjt0i521SH6b0XpopopGVlbY1Rk6gmZtuAwvV9Xr8Z5V42K0U/6CLlHp0VpnK8i7N5'
    b'CNjIrDhzk0h4Qf0g/5TX/wsY0k6SNz8KAgAAAABJRU5ErkJggg==')

#----------------------------------------------------------------------
BtnSmlRd00 = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAArtJ'
    b'REFUOI1tk81vlVUQxn/znnPvfcXbjwuBCLRuNCYmaC5L6Eco1UQNkTbGprrRIBpI2BjDX8Gi'
    b'BDeQgMpGkyY0GiUxftBWpUSIaVET2UCFQmyBtveWt7evfc854+K20hKezWSSmWcmM88jEhke'
    b'xS7x2mqgKPU8UZjycEmNPFpr1ybtxmv7U1t56cARtmx7dl3h9NQ1Lpw9qT9P/8NF/5BIVjfY'
    b'Z7z29fZT7u4FK7iZWcJSioZAFMfYLSUEw/j35xj8apDzKyR2dfKb+/sod/eS/HUNnEODgiqq'
    b'oR6nbiHW8uKr+1HnmD8/pGPeiAXYvXkzO7peo3L5MhoCqvXmzs+OAzDy9qH/idLvZni+o5u2'
    b'X39ibGYeacuhR985xEa/AVyAoGgIdH5+gtH+w2gI7Bk8xYU33kNDAA1gIx40WY6dPU3UIhC7'
    b'QDY3D5mCl3pz3xFwgnhhpPd99p47gzjACbrkeDLEtBqIigIPro6TLVTwtUU6vhjgYv9HGHJE'
    b'kkc0h5BntOcwe7/+FIMl8obFP/6kKCtHTCZvoI01Glrqr9MQAAg5BzkAwaZx/W+pUrt3m+WF'
    b'OQCiRGEpy9DgyapVfuh4i/bBAdxsFeNySCpIKrQNDTC270PcvzUIntpyQqIQ3VaYw2NsAZOP'
    b'MbbASPcB9vz4CcE5ADqHPma4611UlNwTRfINJWazlCkPdswbKfuaPhPHNDeWMI1F/ELCcM9B'
    b'ur48DcDoKx8QFfIsJxUKzSUqi/e5mdzlkq7o4HevbLp7neK254iDxQNUHcM9B6HqoMlC1ZEv'
    b'NrOEMnH9ChPOAeahlF+3Xsul7ex44WW2xk24hvr6oZYSbYgpUGJ64T5Xx7/lt3t/882KlGWt'
    b'G9uN152FmKdbyzRvaqFQKIJAlqVUZu8wOXmFieWUXx5nprVoM163y3o731HWuXAV/wGEbkRk'
    b'8B5+rAAAAABJRU5ErkJggg==')




#----------------------------------------------------------------------------
# Name:         ldmWidThd.py
# Purpose:      ldmWidThd.py
#               GUI widget respond control thread
# Author:       Walter Obweger
#
# Created:      20200414
# CVS-ID:       $Id$
# Copyright:    (c) 2020 by Walter Obweger
# Licence:      MIT
#----------------------------------------------------------------------------

import wx

from lindworm.ldmGuiThd import ldmGuiThd
from lindworm.ldmWidPanel import ldmWidPanel
from lindworm.ldmWidPanel import ldmWidPanelFlxGrd
import lindworm.ldmWidImgMed as ldmWidImgMed

#ldmWidPanelFlxGrd
class ldmWidThd(ldmWidPanelFlxGrd):
    def __init__(self,**kwargs):
        try:
            # +++++ beg:
            _kwargs=self.GetKw(kwargs,[
                        'sLogger','iLv',
                        'id','name','parent',
                        'pos','size','style',
                        'iCol',
                        'lWid'])
            tSz = (16,16)
            bmpSta=bmp=ldmWidImgMed.BtnSmlGn01.GetBitmap()
            bmpStp=bmp=ldmWidImgMed.BtnSmlRd00.GetBitmap()
            lWid=[
                ['lbl'  ,'lblPhase',    'phase'],
                ['txtRd','txtPhase',    ''],
                ['cbBmp','cbStop',    bmpStp,   'stop'],
                ['lbl'  ,'lblStatus',   'status'],
                ['txtRd','txtStatus',   ''],
                ['cbBmp','cbStart',   bmpSta,   'start'],
                
                [None],
                ['gag'  ,'gagDetail',1000],
                [None],
                
                [None],
                ['lst'  ,'lcrThd',      ''],
                [None],
                ]
            lWidArg=_kwargs.get('lWid',None)
            if lWidArg is None:
                _kwargs['lWid']=lWid
            else:
                _kwargs['lWid']=lWid+lWidArg
            _kwargs['iCol']=3
            _kwargs['lCol']=[1]
            _kwargs['lRow']=[3]
            ldmWidPanelFlxGrd.__init__(self,**_kwargs)
            # ----- end:
        except:
            self.logTB()
    def __initObj__(self,**kwargs):
        """initialize object properties, widgets aren't present yet.
        ### parameter
            kwargs  ... keyword arguments passed to all init methods
        """
        try:
            # +++++ beg:initialize
            sOrg='ldmWidCore::__initObj__'
            self.logDbg('beg:%s'%(sOrg))
            # ----- end:initialize
            # +++++ beg:
            self.dFunc={
                'start':('dummy',self.prcDmy,(),{})
                }
            # ----- end:
            # +++++ beg:finalize
            self.logDbg('end:%s'%(sOrg))
            # ----- end:finalize
        except:
            self.logTB()
    def __initWid__(self,**kwargs):
        try:
            self.logDbg('__initWid__')
            ldmWidPanelFlxGrd.__initWid__(self,**kwargs)
            self.lcrThd.AppendColumn("No", format=wx.LIST_FORMAT_LEFT,
                    width=self.getCfgWid('ldmWidThd','iColNo',sType='int',oDft=80))
            self.lcrThd.AppendColumn("Info", format=wx.LIST_FORMAT_LEFT, 
                    width=self.getCfgWid('ldmWidThd','iColInfo',sType='int',oDft=320))
            self.lcrThd.AppendColumn("Stat", format=wx.LIST_FORMAT_LEFT, 
                    width=self.getCfgWid('ldmWidThd','iColStat',sType='int',oDft=30))

            self.oThd=ldmGuiThd(self.GetWid(),rDly=0.2,sLogger='thdGui',iVerbose=0)
            self.oThd.BindEvtNty(self.OnThdNty)
        except:
            self.logTB()
            return -1
    def SetFunc(self,sCmd,sPhase,func,*args,**kwargs):
        try:
            # +++++ beg:
            self.logDbg('ldmWidThd::SetFunc sCmd:%r sPhase:%r',
                        sCmd,sPhase)
            self.dFunc[sCmd]=(sPhase,func,args,kwargs)
            self.logDbg('dFunc:%r',self.dFunc)
        except:
            self.logTB()
            return -1
    def DoCmd(self,sCmd,oThd,oNty):
        try:
            # +++++ beg:
            self.logDbg('ldmWidThd::DoCmd sCmd:%r',sCmd)
            self.logDbg('dFunc:%r',self.dFunc)
            sPhase,func,args,kwargs=self.dFunc.get(sCmd,
                                ('dummy',self.prcDmy,(),{}))
            self.logDbg('%s, func:%r a:%r k:%r',sPhase,func,args,kwargs)
            if sCmd=='start':
                #oNty=self.oThd.GetNty()
                func(*args,oThd=oThd,**kwargs)
                #oThd.Do(sPhase,func,*args,oThd=oThd,**kwargs)
                #self.oThd.Do('dummy',
                #            self.prcDmy,*(),
                #            oNty=oNty)
            elif sCmd=='stop':
                oThd.Stop()
            # ----- end:
            return 0
        except:
            self.logTB()
            return -1
    def prcCmd(self,sCmd):
        try:
            # +++++ beg:
            self.logDbg('ldmWidThd::prcCmd sCmd:%r',sCmd)
            if sCmd=='start':
                oNty=self.oThd.GetNty()
                self.DoCmd(sCmd,self.oThd,oNty)
                #self.oThd.Do('dummy',
                #            self.prcDmy,*(),
                #            oNty=oNty)
            elif sCmd=='stop':
                self.oThd.Stop()
            # ----- end:
            return 0
        except:
            self.logTB()
            return -1
    def GetThd(self):
        return self.oThd
    def OnThdNty(self,evt):
        evt.Skip()
        try:
            # +++++ beg:
            sStatOfs=evt.oNty.GetStatusOfs()
            iVal=evt.oNty.GetNormalized()
            sPhase=evt.oNty.GetPhase()
            sStatus=evt.oNty.GetStatus()
            self.gagDetail.SetValue(int(iVal))
            self.txtPhase.SetValue(sPhase)
            self.txtStatus.SetValue(sStatus)
            iIdx=self.lcrThd.InsertItem(0,sStatOfs)
            self.lcrThd.SetItem(iIdx,1,sStatus)
            # ----- end:
        except:
            self.logTB()
    def prcDmy(self,oNty=None):
        try:
            # +++++ beg:initialize
            iRet=0
            sOrg='ldmWidThd::prcDmy'
            self.logDbg('beg:%s',sOrg)
            # ----- end:initialize
            # +++++ beg:action
            if oNty is not None:
                oNty.SetPhase('process dummy')
                oNty.SetStatus('loop')
                oNty.IncStatus()
                oNty.SetMax(10)
            for iOfs in range(10):
                self.oThd.delay()
                if oNty is not None:
                    oNty.SetVal(iOfs)
            # ----- end:action
            # +++++ beg:finalize
            if oNty is not None:
                oNty.SetPhase('finished.')
                oNty.SetStatus('all good')
            # ----- end:finalize
            # +++++ beg:
            if oNty is not None:
                oNty.finStatus()
                self.oThd.delay(iCnt=5)
            self.logDbg('end:%s iRet:%d',sOrg,iRet)
            # ----- end:
            return iRet
        except:
            self.oFdr.logTB()
            return -1
